@@ -1,13 +1,14 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
 Contains the transformation functions for getting from ICRS/HCRS to CIRS and
-anything in between (currently that means GCRS)
+anything in between (currently that means GCRS).
 """
 
 import numpy as np
 
 from astropy import units as u
 from astropy.coordinates.baseframe import frame_transform_graph
+from astropy.coordinates.erfa_astrom import erfa_astrom
 from astropy.coordinates.representation import (
     CartesianRepresentation,
     SphericalRepresentation,
@@ -18,7 +19,6 @@ from astropy.coordinates.transformations import (
     FunctionTransformWithFiniteDifference,
 )
 
-from ..erfa_astrom import erfa_astrom
 from .cirs import CIRS
 from .gcrs import GCRS
 from .hcrs import HCRS
