@@ -183,7 +183,7 @@ def read_table_fits(
     """
     if isinstance(input, HDUList):
         # Parse all table objects
-        tables = dict()
+        tables = {}
         for ihdu, hdu_item in enumerate(input):
             if isinstance(hdu_item, (TableHDU, BinTableHDU, GroupsHDU)):
                 tables[ihdu] = hdu_item
@@ -265,21 +265,32 @@ def read_table_fits(
         # string, empty strings.
         # Since Multi-element columns with dtypes such as '2f8' have a subdtype,
         # we should look up the type of column on that.
+        # Also propagate TNULL (for ints) or the FITS default null value for
+        # floats and strings to the column's fill_value to ensure round trips
+        # preserve null values.
         masked = mask = False
+        fill_value = None
         coltype = col.dtype.subdtype[0].type if col.dtype.subdtype else col.dtype.type
         if col.null is not None:
             mask = data[col.name] == col.null
             # Return a MaskedColumn even if no elements are masked so
             # we roundtrip better.
             masked = True
+            fill_value = col.null
         elif mask_invalid and issubclass(coltype, np.inexact):
             mask = np.isnan(data[col.name])
+            fill_value = np.nan
         elif mask_invalid and issubclass(coltype, np.character):
             mask = col.array == b""
+            fill_value = b""
 
         if masked or np.any(mask):
             column = MaskedColumn(
-                data=data[col.name], name=col.name, mask=mask, copy=False
+                data=data[col.name],
+                name=col.name,
+                mask=mask,
+                copy=False,
+                fill_value=fill_value,
             )
         else:
             column = Column(data=data[col.name], name=col.name, copy=False)
