@@ -29,8 +29,8 @@ from astropy.utils import indent
 from astropy.utils.compat.optional_deps import HAS_BZ2
 from astropy.utils.exceptions import AstropyUserWarning
 
-from . import compressed
 from .base import ExtensionHDU, _BaseHDU, _NonstandardHDU, _ValidHDU
+from .compressed import compressed
 from .groups import GroupsHDU
 from .image import ImageHDU, PrimaryHDU
 
@@ -54,6 +54,7 @@ def fitsopen(
     *,
     use_fsspec=None,
     fsspec_kwargs=None,
+    decompress_in_memory=False,
     **kwargs,
 ):
     """Factory function to open a FITS file and return an `HDUList` object.
@@ -184,6 +185,14 @@ def fitsopen(
 
         .. versionadded:: 5.2
 
+    decompress_in_memory : bool, optional
+        By default files are decompressed progressively depending on what data
+        is needed.  This is good for memory usage, avoiding decompression of
+        the whole file, but it can be slow. With decompress_in_memory=True it
+        is possible to decompress instead the whole file in memory.
+
+        .. versionadded:: 6.0
+
     Returns
     -------
     hdulist : `HDUList`
@@ -220,6 +229,7 @@ def fitsopen(
         ignore_missing_simple,
         use_fsspec=use_fsspec,
         fsspec_kwargs=fsspec_kwargs,
+        decompress_in_memory=decompress_in_memory,
         **kwargs,
     )
 
@@ -890,7 +900,7 @@ class HDUList(list, _Verify):
         if save_backup and self._file.mode in ("append", "update"):
             filename = self._file.name
             if os.path.exists(filename):
-                # The the file doesn't actually exist anymore for some reason
+                # The file doesn't actually exist anymore for some reason
                 # then there's no point in trying to make a backup
                 backup = filename + ".bak"
                 idx = 1
@@ -1133,6 +1143,7 @@ class HDUList(list, _Verify):
         *,
         use_fsspec=None,
         fsspec_kwargs=None,
+        decompress_in_memory=False,
         **kwargs,
     ):
         """
@@ -1150,6 +1161,7 @@ class HDUList(list, _Verify):
                     cache=cache,
                     use_fsspec=use_fsspec,
                     fsspec_kwargs=fsspec_kwargs,
+                    decompress_in_memory=decompress_in_memory,
                 )
             # The Astropy mode is determined by the _File initializer if the
             # supplied mode was None
@@ -1323,10 +1335,10 @@ class HDUList(list, _Verify):
             # corrupted HDU
             except (VerifyError, ValueError) as exc:
                 warnings.warn(
-                    "Error validating header for HDU #{} (note: Astropy "
-                    "uses zero-based indexing).\n{}\n"
+                    f"Error validating header for HDU #{len(self)} (note: Astropy "
+                    f"uses zero-based indexing).\n{indent(str(exc))}\n"
                     "There may be extra bytes after the last HDU or the "
-                    "file is corrupted.".format(len(self), indent(str(exc))),
+                    "file is corrupted.",
                     VerifyWarning,
                 )
                 del exc
@@ -1380,7 +1392,7 @@ class HDUList(list, _Verify):
         # each element calls their own verify
         for idx, hdu in enumerate(self):
             if idx > 0 and (not isinstance(hdu, ExtensionHDU)):
-                err_text = f"HDUList's element {str(idx)} is not an extension HDU."
+                err_text = f"HDUList's element {idx} is not an extension HDU."
 
                 err = self.run_option(option, err_text=err_text, fixable=False)
                 errs.append(err)
