@@ -179,7 +179,6 @@ class _ImageBaseHDU(_ValidHDU):
         _ImageBaseHDU is sort of an abstract class for HDUs containing image
         data (as opposed to table data) and should never be used directly.
         """
-
         raise NotImplementedError
 
     @property
@@ -211,7 +210,6 @@ class _ImageBaseHDU(_ValidHDU):
         :ref:`astropy:data-sections` section of the documentation for
         more details.
         """
-
         return Section(self)
 
     @property
@@ -219,7 +217,6 @@ class _ImageBaseHDU(_ValidHDU):
         """
         Shape of the image array--should be equivalent to ``self.data.shape``.
         """
-
         # Determine from the values read from the header
         return tuple(reversed(self._axes))
 
@@ -247,7 +244,6 @@ class _ImageBaseHDU(_ValidHDU):
         attribute returns the data scaled to its physical values unless the
         file was opened with ``do_not_scale_image_data=True``.
         """
-
         if len(self._axes) < 1:
             return
 
@@ -268,19 +264,16 @@ class _ImageBaseHDU(_ValidHDU):
             self._data_replaced = True
             was_unsigned = False
 
-        if (
-            data is not None
-            and not isinstance(data, np.ndarray)
-            and not _is_dask_array(data)
-        ):
-            # Try to coerce the data into a numpy array--this will work, on
-            # some level, for most objects
-            try:
-                data = np.array(data)
-            except Exception:
-                raise TypeError(
-                    f"data object {data!r} could not be coerced into an ndarray"
-                )
+        if data is not None:
+            if not isinstance(data, np.ndarray) and not _is_dask_array(data):
+                # Try to coerce the data into a numpy array--this will work, on
+                # some level, for most objects
+                try:
+                    data = np.array(data)
+                except Exception:  # pragma: no cover
+                    raise TypeError(
+                        f"data object {data!r} could not be coerced into an ndarray"
+                    )
 
             if data.shape == ():
                 raise TypeError(
@@ -290,7 +283,7 @@ class _ImageBaseHDU(_ValidHDU):
         self.__dict__["data"] = data
         self._modified = True
 
-        if self.data is None:
+        if data is None:
             self._axes = []
         else:
             # Set new values of bitpix, bzero, and bscale now, but wait to
@@ -330,7 +323,6 @@ class _ImageBaseHDU(_ValidHDU):
         """
         Update the header keywords to agree with the data.
         """
-
         if not (
             self._modified
             or self._header._modified
@@ -399,7 +391,6 @@ class _ImageBaseHDU(_ValidHDU):
         """
         Delete BSCALE/BZERO from header if necessary.
         """
-
         # Note that _dtype_for_bitpix determines the dtype based on the
         # "original" values of bitpix, bscale, and bzero, stored in
         # self._orig_bitpix, etc. It contains the logic for determining which
@@ -479,7 +470,6 @@ class _ImageBaseHDU(_ValidHDU):
         bscale, bzero : int, optional
             User-specified ``BSCALE`` and ``BZERO`` values
         """
-
         # Disable blank support for now
         self._scale_internal(
             type=type, option=option, bscale=bscale, bzero=bzero, blank=None
@@ -502,7 +492,6 @@ class _ImageBaseHDU(_ValidHDU):
         conversion of floats to ints without specifying a BLANK if there are
         NaN/inf values).
         """
-
         if self.data is None:
             return
 
@@ -559,7 +548,7 @@ class _ImageBaseHDU(_ValidHDU):
                 # We have to explicitly cast _zero to prevent numpy from raising an
                 # error when doing self.data -= zero, and we do this instead of
                 # self.data = self.data - zero to avoid doubling memory usage.
-                np.add(self.data, -_zero, out=self.data, casting="unsafe")
+                self.data -= np.array(_zero).astype(self.data.dtype, casting="unsafe")
             self._header["BZERO"] = _zero
         else:
             try:
@@ -621,9 +610,9 @@ class _ImageBaseHDU(_ValidHDU):
         # should be handled by the schema
         if not _is_int(self._blank):
             messages.append(
-                "Invalid value for 'BLANK' keyword in header: {!r} "
+                f"Invalid value for 'BLANK' keyword in header: {self._blank!r} "
                 "The 'BLANK' keyword must be an integer.  It will be "
-                "ignored in the meantime.".format(self._blank)
+                "ignored in the meantime."
             )
             self._blank = None
         if not self._bitpix > 0:
@@ -767,7 +756,6 @@ class _ImageBaseHDU(_ValidHDU):
         the BITPIX value in the header, and possibly on the BSCALE value as
         well.  Returns None if there should not be any change.
         """
-
         bitpix = self._orig_bitpix
         # Handle possible conversion to uints if enabled
         if self._uint and self._orig_bscale == 1:
@@ -796,7 +784,6 @@ class _ImageBaseHDU(_ValidHDU):
         since we can't do NaNs with integers, anyway, i.e. the user is
         responsible for managing blanks.
         """
-
         dtype = self._dtype_for_bitpix()
         # bool(dtype) is always False--have to explicitly compare to None; this
         # caused a fair amount of hair loss
@@ -817,7 +804,6 @@ class _ImageBaseHDU(_ValidHDU):
         factors to it.  Normally this is used for the entire image, but it
         supports alternate offset/shape for Section support.
         """
-
         code = BITPIX2DTYPE[self._orig_bitpix]
 
         raw_data = self._get_raw_data(shape, code, offset)
@@ -890,7 +876,6 @@ class _ImageBaseHDU(_ValidHDU):
         """
         Summarize the HDU: name, dimensions, and formats.
         """
-
         class_name = self.__class__.__name__
 
         # if data is touched, use data info.
@@ -926,7 +911,6 @@ class _ImageBaseHDU(_ValidHDU):
         """
         Calculate the value for the ``DATASUM`` card in the HDU.
         """
-
         if self._has_data:
             # We have the data to be used.
             d = self.data
@@ -1066,7 +1050,8 @@ class Section:
             if isinstance(key, slice):
                 ks = range(*key.indices(axis))
                 break
-            elif isiterable(key):
+
+            if isiterable(key):
                 # Handle both integer and boolean arrays.
                 ks = np.arange(axis, dtype=int)[key]
                 break
@@ -1135,7 +1120,6 @@ class PrimaryHDU(_ImageBaseHDU):
             rescaled unless scale_back is explicitly set to `False`.
             (default: None)
         """
-
         super().__init__(
             data=data,
             header=header,
@@ -1159,7 +1143,7 @@ class PrimaryHDU(_ImageBaseHDU):
         # keyword to be True/False, have to check the value
         return (
             card.keyword == "SIMPLE"
-            and ("GROUPS" not in header or header["GROUPS"] != True)  # noqa: E712
+            and ("GROUPS" not in header or header["GROUPS"] is not True)
             and card.value
         )
 
@@ -1248,7 +1232,6 @@ class ImageHDU(_ImageBaseHDU, ExtensionHDU):
             card of the ``header`` or 1.
             (default: None)
         """
-
         # This __init__ currently does nothing differently from the base class,
         # and is only explicitly defined for the docstring.
 
@@ -1274,7 +1257,6 @@ class ImageHDU(_ImageBaseHDU, ExtensionHDU):
         """
         ImageHDU verify method.
         """
-
         errs = super()._verify(option=option)
         naxis = self._header.get("NAXIS", 0)
         # PCOUNT must == 0, GCOUNT must == 1; the former is verified in
