@@ -5,18 +5,36 @@ Observatory (VO) initiative, particularly the VOTable XML format.
 """
 
 
-from .table import (
-    parse, parse_single_table, validate, from_table, is_votable, writeto)
-from .exceptions import (
-    VOWarning, VOTableChangeWarning, VOTableSpecWarning, UnimplementedWarning,
-    IOWarning, VOTableSpecError)
 from astropy import config as _config
 
+from .exceptions import (
+    IOWarning,
+    UnimplementedWarning,
+    VOTableChangeWarning,
+    VOTableSpecError,
+    VOTableSpecWarning,
+    VOWarning,
+)
+from .table import from_table, is_votable, parse, parse_single_table, validate, writeto
+
 __all__ = [
-    'Conf', 'conf', 'parse', 'parse_single_table', 'validate',
-    'from_table', 'is_votable', 'writeto', 'VOWarning',
-    'VOTableChangeWarning', 'VOTableSpecWarning',
-    'UnimplementedWarning', 'IOWarning', 'VOTableSpecError']
+    "Conf",
+    "conf",
+    "parse",
+    "parse_single_table",
+    "validate",
+    "from_table",
+    "is_votable",
+    "writeto",
+    "VOWarning",
+    "VOTableChangeWarning",
+    "VOTableSpecWarning",
+    "UnimplementedWarning",
+    "IOWarning",
+    "VOTableSpecError",
+]
+
+VERIFY_OPTIONS = ["ignore", "warn", "exception"]  # First one is default
 
 
 class Conf(_config.ConfigNamespace):
@@ -25,12 +43,11 @@ class Conf(_config.ConfigNamespace):
     """
 
     verify = _config.ConfigItem(
-        'ignore',
+        VERIFY_OPTIONS,
         "Can be 'exception' (treat fixable violations of the VOTable spec as "
         "exceptions), 'warn' (show warnings for VOTable spec violations), or "
         "'ignore' (silently ignore VOTable spec violations)",
-        aliases=['astropy.io.votable.table.pedantic',
-                 'astropy.io.votable.pedantic'])
+    )
 
 
 conf = Conf()
