@@ -4,6 +4,8 @@ This module contains models representing polynomials and polynomial series.
 
 """
 # pylint: disable=invalid-name
+from math import comb
+
 import numpy as np
 
 from astropy.utils import check_broadcast, indent
@@ -11,7 +13,7 @@ from astropy.utils import check_broadcast, indent
 from .core import FittableModel, Model
 from .functional_models import Shift
 from .parameters import Parameter
-from .utils import _validate_domain_window, comb, poly_map_domain
+from .utils import _validate_domain_window, poly_map_domain
 
 __all__ = [
     "Chebyshev1D",
@@ -58,7 +60,6 @@ class PolynomialBase(FittableModel):
         can have different parameters depending on the degree of the polynomial
         and the number of dimensions, for example.
         """
-
         return self._param_names
 
 
@@ -99,14 +100,12 @@ class PolynomialModel(PolynomialBase):
     @property
     def degree(self):
         """Degree of polynomial."""
-
         return self._degree
 
     def get_num_coeff(self, ndim):
         """
-        Return the number of coefficients in one parameter set
+        Return the number of coefficients in one parameter set.
         """
-
         if self.degree < 0:
             raise ValueError("Degree of polynomial must be positive or null")
         # deg+1 is used to account for the difference between iraf using
@@ -187,7 +186,6 @@ class _PolyDomainWindow1D(PolynomialModel):
         This method sets the ``domain`` and ``window`` attributes on 1D subclasses.
 
         """
-
         self._default_domain_window = {"domain": None, "window": (-1, 1)}
         self.window = window or (-1, 1)
         self.domain = domain
@@ -218,7 +216,6 @@ class OrthoPolynomialBase(PolynomialBase):
 
     Parameters
     ----------
-
     x_degree : int
         degree in x
     y_degree : int
@@ -347,14 +344,13 @@ class OrthoPolynomialBase(PolynomialBase):
 
     def get_num_coeff(self):
         """
-        Determine how many coefficients are needed
+        Determine how many coefficients are needed.
 
         Returns
         -------
         numc : int
             number of coefficients
         """
-
         if self.x_degree < 0 or self.y_degree < 0:
             raise ValueError("Degree of polynomial must be positive or null")
 
@@ -437,7 +433,6 @@ class OrthoPolynomialBase(PolynomialBase):
 
         To be implemented by subclasses"
         """
-
         raise NotImplementedError("Subclasses should implement this")
 
     def evaluate(self, x, y, *coeffs):
@@ -487,7 +482,6 @@ class Chebyshev1D(_PolyDomainWindow1D):
 
     Notes
     -----
-
     This model does not support the use of units/quantities, because each term
     in the sum of Chebyshev polynomials is a polynomial in x - since the
     coefficients within each Chebyshev polynomial are fixed, we can't use
@@ -495,6 +489,7 @@ class Chebyshev1D(_PolyDomainWindow1D):
     third Chebyshev polynomial (T2) is 2x^2-1, but if x was specified with
     units, 2x^2 and -1 would have incompatible units.
     """
+
     n_inputs = 1
     n_outputs = 1
 
@@ -538,7 +533,6 @@ class Chebyshev1D(_PolyDomainWindow1D):
         result : ndarray
             The Vandermonde matrix
         """
-
         x = np.array(x, dtype=float, copy=False, ndmin=1)
         v = np.empty((self.degree + 1,) + x.shape, dtype=x.dtype)
         v[0] = 1
@@ -564,7 +558,6 @@ class Chebyshev1D(_PolyDomainWindow1D):
     @staticmethod
     def clenshaw(x, coeffs):
         """Evaluates the polynomial using Clenshaw's algorithm."""
-
         if len(coeffs) == 1:
             c0 = coeffs[0]
             c1 = 0
@@ -610,7 +603,6 @@ class Hermite1D(_PolyDomainWindow1D):
 
     Notes
     -----
-
     This model does not support the use of units/quantities, because each term
     in the sum of Hermite polynomials is a polynomial in x - since the
     coefficients within each Hermite polynomial are fixed, we can't use
@@ -618,6 +610,7 @@ class Hermite1D(_PolyDomainWindow1D):
     third Hermite polynomial (H2) is 4x^2-2, but if x was specified with units,
     4x^2 and -2 would have incompatible units.
     """
+
     n_inputs = 1
     n_outputs = 1
 
@@ -661,7 +654,6 @@ class Hermite1D(_PolyDomainWindow1D):
         result : ndarray
             The Vandermonde matrix
         """
-
         x = np.array(x, dtype=float, copy=False, ndmin=1)
         v = np.empty((self.degree + 1,) + x.shape, dtype=x.dtype)
         v[0] = 1
@@ -720,7 +712,6 @@ class Hermite2D(OrthoPolynomialBase):
 
     Parameters
     ----------
-
     x_degree : int
         degree in x
     y_degree : int
@@ -742,7 +733,6 @@ class Hermite2D(OrthoPolynomialBase):
 
     Notes
     -----
-
     This model does not support the use of units/quantities, because each term
     in the sum of Hermite polynomials is a polynomial in x and/or y - since the
     coefficients within each Hermite polynomial are fixed, we can't use
@@ -750,6 +740,7 @@ class Hermite2D(OrthoPolynomialBase):
     example, the third Hermite polynomial (H2) is 4x^2-2, but if x was
     specified with units, 4x^2 and -2 would have incompatible units.
     """
+
     _separable = False
 
     def __init__(
@@ -785,7 +776,6 @@ class Hermite2D(OrthoPolynomialBase):
         Calculate the individual Hermite functions once and store them in a
         dictionary to be reused.
         """
-
         x_terms = self.x_degree + 1
         y_terms = self.y_degree + 1
         kfunc = {}
@@ -823,7 +813,6 @@ class Hermite2D(OrthoPolynomialBase):
         result : ndarray
             The Vandermonde matrix
         """
-
         if x.shape != y.shape:
             raise ValueError("x and y must have the same shape")
 
@@ -842,9 +831,8 @@ class Hermite2D(OrthoPolynomialBase):
 
     def _hermderiv1d(self, x, deg):
         """
-        Derivative of 1D Hermite series
+        Derivative of 1D Hermite series.
         """
-
         x = np.array(x, dtype=float, copy=False, ndmin=1)
         d = np.empty((deg + 1, len(x)), dtype=x.dtype)
         d[0] = x * 0 + 1
@@ -885,7 +873,6 @@ class Legendre1D(_PolyDomainWindow1D):
 
     Notes
     -----
-
     This model does not support the use of units/quantities, because each term
     in the sum of Legendre polynomials is a polynomial in x - since the
     coefficients within each Legendre polynomial are fixed, we can't use
@@ -949,7 +936,6 @@ class Legendre1D(_PolyDomainWindow1D):
         result : ndarray
             The Vandermonde matrix
         """
-
         x = np.array(x, dtype=float, copy=False, ndmin=1)
         v = np.empty((self.degree + 1,) + x.shape, dtype=x.dtype)
         v[0] = 1
@@ -1069,7 +1055,6 @@ class Polynomial1D(_PolyDomainWindow1D):
         result : ndarray
             The Vandermonde matrix
         """
-
         v = np.empty((self.degree + 1,) + x.shape, dtype=float)
         v[0] = 1
         if self.degree > 0:
@@ -1090,10 +1075,10 @@ class Polynomial1D(_PolyDomainWindow1D):
 
     @property
     def input_units(self):
-        if self.degree == 0 or self.c1.unit is None:
+        if self.degree == 0 or self.c1.input_unit is None:
             return None
         else:
-            return {self.inputs[0]: self.c0.unit / self.c1.unit}
+            return {self.inputs[0]: self.c0.input_unit / self.c1.input_unit}
 
     def _parameter_units_for_data_units(self, inputs_unit, outputs_unit):
         mapping = {}
@@ -1251,7 +1236,6 @@ class Polynomial2D(PolynomialModel):
         result : ndarray
             The Vandermonde matrix
         """
-
         if x.ndim == 2:
             x = x.flatten()
         if y.ndim == 2:
@@ -1287,7 +1271,7 @@ class Polynomial2D(PolynomialModel):
 
     def multivariate_horner(self, x, y, coeffs):
         """
-        Multivariate Horner's scheme
+        Multivariate Horner's scheme.
 
         Parameters
         ----------
@@ -1295,7 +1279,6 @@ class Polynomial2D(PolynomialModel):
         coeffs : array
             Coefficients in inverse lexical order.
         """
-
         alpha = self._invlex()
         r0 = coeffs[0]
         r1 = r0 * 0.0
@@ -1313,11 +1296,13 @@ class Polynomial2D(PolynomialModel):
 
     @property
     def input_units(self):
-        if self.degree == 0 or (self.c1_0.unit is None and self.c0_1.unit is None):
+        if self.degree == 0 or (
+            self.c1_0.input_unit is None and self.c0_1.input_unit is None
+        ):
             return None
         return {
-            self.inputs[0]: self.c0_0.unit / self.c1_0.unit,
-            self.inputs[1]: self.c0_0.unit / self.c0_1.unit,
+            self.inputs[0]: self.c0_0.input_unit / self.c1_0.input_unit,
+            self.inputs[1]: self.c0_0.input_unit / self.c0_1.input_unit,
         }
 
     def _parameter_units_for_data_units(self, inputs_unit, outputs_unit):
@@ -1382,7 +1367,6 @@ class Chebyshev2D(OrthoPolynomialBase):
 
     Parameters
     ----------
-
     x_degree : int
         degree in x
     y_degree : int
@@ -1405,7 +1389,6 @@ class Chebyshev2D(OrthoPolynomialBase):
 
     Notes
     -----
-
     This model does not support the use of units/quantities, because each term
     in the sum of Chebyshev polynomials is a polynomial in x and/or y - since
     the coefficients within each Chebyshev polynomial are fixed, we can't use
@@ -1413,6 +1396,7 @@ class Chebyshev2D(OrthoPolynomialBase):
     example, the third Chebyshev polynomial (T2) is 2x^2-1, but if x was
     specified with units, 2x^2 and -1 would have incompatible units.
     """
+
     _separable = False
 
     def __init__(
@@ -1448,7 +1432,6 @@ class Chebyshev2D(OrthoPolynomialBase):
         Calculate the individual Chebyshev functions once and store them in a
         dictionary to be reused.
         """
-
         x_terms = self.x_degree + 1
         y_terms = self.y_degree + 1
         kfunc = {}
@@ -1486,7 +1469,6 @@ class Chebyshev2D(OrthoPolynomialBase):
         result : ndarray
             The Vandermonde matrix
         """
-
         if x.shape != y.shape:
             raise ValueError("x and y must have the same shape")
 
@@ -1505,9 +1487,8 @@ class Chebyshev2D(OrthoPolynomialBase):
 
     def _chebderiv1d(self, x, deg):
         """
-        Derivative of 1D Chebyshev series
+        Derivative of 1D Chebyshev series.
         """
-
         x = np.array(x, dtype=float, copy=False, ndmin=1)
         d = np.empty((deg + 1, len(x)), dtype=x.dtype)
         d[0] = x * 0 + 1
@@ -1534,7 +1515,6 @@ class Legendre2D(OrthoPolynomialBase):
 
     Parameters
     ----------
-
     x_degree : int
         degree in x
     y_degree : int
@@ -1571,6 +1551,7 @@ class Legendre2D(OrthoPolynomialBase):
     third Legendre polynomial (P2) is 1.5x^2-0.5, but if x was specified with
     units, 1.5x^2 and -0.5 would have incompatible units.
     """
+
     _separable = False
 
     def __init__(
@@ -1606,7 +1587,6 @@ class Legendre2D(OrthoPolynomialBase):
         Calculate the individual Legendre functions once and store them in a
         dictionary to be reused.
         """
-
         x_terms = self.x_degree + 1
         y_terms = self.y_degree + 1
         kfunc = {}
@@ -1626,8 +1606,8 @@ class Legendre2D(OrthoPolynomialBase):
         return kfunc
 
     def fit_deriv(self, x, y, *params):
-        """
-        Derivatives with respect to the coefficients.
+        """Derivatives with respect to the coefficients.
+
         This is an array with Legendre polynomials:
 
         Lx0Ly0  Lx1Ly0...LxnLy0...LxnLym
@@ -1662,8 +1642,7 @@ class Legendre2D(OrthoPolynomialBase):
         return v.T
 
     def _legendderiv1d(self, x, deg):
-        """Derivative of 1D Legendre polynomial"""
-
+        """Derivative of 1D Legendre polynomial."""
         x = np.array(x, dtype=float, copy=False, ndmin=1)
         d = np.empty((deg + 1,) + x.shape, dtype=x.dtype)
         d[0] = x * 0 + 1
@@ -1735,9 +1714,8 @@ class _SIP1D(PolynomialBase):
 
     def get_num_coeff(self, ndim):
         """
-        Return the number of coefficients in one param set
+        Return the number of coefficients in one param set.
         """
-
         if self.order < 2 or self.order > 9:
             raise ValueError("Degree of polynomial must be 2< deg < 9")
 
@@ -1762,15 +1740,15 @@ class _SIP1D(PolynomialBase):
         mat = np.zeros((self.order + 1, self.order + 1))
         for i in range(2, self.order + 1):
             attr = f"{coeff_prefix}_{i}_{0}"
-            mat[i, 0] = coeffs[self.param_names.index(attr)]
+            mat[i, 0] = coeffs[self.param_names.index(attr)][0]
         for i in range(2, self.order + 1):
             attr = f"{coeff_prefix}_{0}_{i}"
-            mat[0, i] = coeffs[self.param_names.index(attr)]
+            mat[0, i] = coeffs[self.param_names.index(attr)][0]
         for i in range(1, self.order):
             for j in range(1, self.order):
                 if i + j < self.order + 1:
                     attr = f"{coeff_prefix}_{i}_{j}"
-                    mat[i, j] = coeffs[self.param_names.index(attr)]
+                    mat[i, j] = coeffs[self.param_names.index(attr)][0]
         return mat
 
     def _eval_sip(self, x, y, coef):
@@ -1907,7 +1885,7 @@ class SIP(Model):
 
 class InverseSIP(Model):
     """
-    Inverse Simple Imaging Polynomial
+    Inverse Simple Imaging Polynomial.
 
     Parameters
     ----------
