@@ -77,7 +77,11 @@ __all__ = [
     "HEALPix",
     "AffineTransformation2D",
     "projcodes",
-] + list(map("_".join, product(["Pix2Sky", "Sky2Pix"], chain(*_PROJ_NAME_CODE))))
+]
+
+__all__ += list(  # noqa: PLE0605
+    map("_".join, product(["Pix2Sky", "Sky2Pix"], chain(*_PROJ_NAME_CODE)))
+)
 
 
 class _ParameterDS(Parameter):
@@ -158,6 +162,18 @@ class Projection(Model):
             self._prj.pv = None, *pv
             self._prj.set()
 
+    def __getstate__(self):
+        return {
+            "p": self.parameters,
+            "fixed": self.fixed,
+            "tied": self.tied,
+            "bounds": self.bounds,
+        }
+
+    def __setstate__(self, state):
+        params = state.pop("p")
+        return self.__init__(*params, **state)
+
 
 class Pix2SkyProjection(Projection):
     """Base class for all Pix2Sky projections."""
@@ -309,13 +325,14 @@ class Pix2Sky_ZenithalPerspective(Pix2SkyProjection, Zenithal):
         description="Look angle γ in degrees (Default = 0°)",
     )
 
-    @mu.validator
-    def mu(self, value):
+    def _mu_validator(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
                 "Zenithal perspective projection is not defined for mu = -1"
             )
 
+    mu._validator = _mu_validator
+
 
 class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
     r"""
@@ -354,13 +371,14 @@ class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
         description="Look angle γ in degrees (Default=0°)",
     )
 
-    @mu.validator
-    def mu(self, value):
+    def _mu_validator(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
                 "Zenithal perspective projection is not defined for mu = -1"
             )
 
+    mu._validator = _mu_validator
+
 
 class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
     r"""
@@ -400,13 +418,14 @@ class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
         description="The latitude θ₀ of the reference point, in degrees (Default=0°)",
     )
 
-    @mu.validator
-    def mu(self, value):
+    def _mu_validator(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
                 "Zenithal perspective projection is not defined for mu = -1"
             )
 
+    mu._validator = _mu_validator
+
 
 class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
     r"""
@@ -446,13 +465,14 @@ class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
         description="The latitude θ₀ of the reference point, in degrees",
     )
 
-    @mu.validator
-    def mu(self, value):
+    def _mu_validator(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
                 "Zenithal perspective projection is not defined for mu = -1"
             )
 
+    mu._validator = _mu_validator
+
 
 class Pix2Sky_Gnomonic(Pix2SkyProjection, Zenithal):
     r"""
@@ -709,16 +729,18 @@ class Pix2Sky_CylindricalPerspective(Pix2SkyProjection, Cylindrical):
     mu = _ParameterDS(default=1.0)
     lam = _ParameterDS(default=1.0)
 
-    @mu.validator
-    def mu(self, value):
+    def _mu_validator(self, value):
         if np.any(value == -self.lam):
             raise InputParameterError("CYP projection is not defined for mu = -lambda")
 
-    @lam.validator
-    def lam(self, value):
+    mu._validator = _mu_validator
+
+    def _lam_validator(self, value):
         if np.any(value == -self.mu):
             raise InputParameterError("CYP projection is not defined for lambda = -mu")
 
+    lam._validator = _lam_validator
+
 
 class Sky2Pix_CylindricalPerspective(Sky2PixProjection, Cylindrical):
     r"""
@@ -748,16 +770,18 @@ class Sky2Pix_CylindricalPerspective(Sky2PixProjection, Cylindrical):
         default=1.0, description="Radius of the cylinder in spherical radii"
     )
 
-    @mu.validator
-    def mu(self, value):
+    def _mu_validator(self, value):
         if np.any(value == -self.lam):
             raise InputParameterError("CYP projection is not defined for mu = -lambda")
 
-    @lam.validator
-    def lam(self, value):
+    mu._validator = _mu_validator
+
+    def _lam_validator(self, value):
         if np.any(value == -self.mu):
             raise InputParameterError("CYP projection is not defined for lambda = -mu")
 
+    lam._validator = _lam_validator
+
 
 class Pix2Sky_CylindricalEqualArea(Pix2SkyProjection, Cylindrical):
     r"""
@@ -1527,16 +1551,16 @@ class AffineTransformation2D(Model):
     matrix = Parameter(default=[[1.0, 0.0], [0.0, 1.0]])
     translation = Parameter(default=[0.0, 0.0])
 
-    @matrix.validator
-    def matrix(self, value):
+    def _matrix_validator(self, value):
         """Validates that the input matrix is a 2x2 2D array."""
         if np.shape(value) != (2, 2):
             raise InputParameterError(
                 "Expected transformation matrix to be a 2x2 array"
             )
 
-    @translation.validator
-    def translation(self, value):
+    matrix._validator = _matrix_validator
+
+    def _translation_validator(self, value):
         """
         Validates that the translation vector is a 2D vector.  This allows
         either a "row" vector or a "column" vector where in the latter case the
@@ -1551,6 +1575,8 @@ class AffineTransformation2D(Model):
                 "vector array"
             )
 
+    translation._validator = _translation_validator
+
     def __init__(self, matrix=matrix, translation=translation, **kwargs):
         super().__init__(matrix=matrix, translation=translation, **kwargs)
         self.inputs = ("x", "y")
