@@ -3,19 +3,23 @@
 """
 Tests that relate to using quantities/units on parameters of models.
 """
-# pylint: disable=invalid-name, no-member
-
 import numpy as np
 import pytest
 
-from astropy.modeling.core import Fittable1DModel, InputParameterError
-from astropy.modeling.parameters import Parameter, ParameterDefinitionError
-from astropy.modeling.models import (Gaussian1D, Pix2Sky_TAN, RotateNative2Celestial,
-                                     Rotation2D)
-from astropy import units as u
-from astropy.units import UnitsError
-from astropy.tests.helper import assert_quantity_allclose
 from astropy import coordinates as coord
+from astropy import units as u
+from astropy.modeling.core import Fittable1DModel, InputParameterError
+from astropy.modeling.models import (
+    BlackBody,
+    Const1D,
+    Gaussian1D,
+    Pix2Sky_TAN,
+    RotateNative2Celestial,
+    Rotation2D,
+)
+from astropy.modeling.parameters import Parameter, ParameterDefinitionError
+from astropy.tests.helper import assert_quantity_allclose
+from astropy.units import UnitsError
 
 
 class BaseTestModel(Fittable1DModel):
@@ -82,11 +86,12 @@ def test_parameter_lose_units():
 
     g = Gaussian1D(1 * u.Jy, 3, 0.1)
 
-    with pytest.raises(UnitsError) as exc:
+    MESSAGE = (
+        r"The .* parameter should be given as a .* because it was originally"
+        r" initialized as a .*"
+    )
+    with pytest.raises(UnitsError, match=MESSAGE):
         g.amplitude = 2
-    assert exc.value.args[0] == ("The 'amplitude' parameter should be given as "
-                                 "a Quantity because it was originally "
-                                 "initialized as a Quantity")
 
 
 def test_parameter_add_units():
@@ -111,16 +116,20 @@ def test_parameter_change_unit():
     g = Gaussian1D(1, 1 * u.m, 0.1 * u.m)
 
     # Setting a unit on a unitless parameter should not work
-    with pytest.raises(ValueError) as exc:
+    MESSAGE = (
+        r"Cannot attach units to parameters that were not initially specified with"
+        r" units"
+    )
+    with pytest.raises(ValueError, match=MESSAGE):
         g.amplitude.unit = u.Jy
-    assert exc.value.args[0] == ("Cannot attach units to parameters that were "
-                                 "not initially specified with units")
 
     # But changing to another unit should not, even if it is an equivalent unit
-    with pytest.raises(ValueError) as exc:
+    MESSAGE = (
+        r"Cannot change the unit attribute directly, instead change the parameter to a"
+        r" new quantity"
+    )
+    with pytest.raises(ValueError, match=MESSAGE):
         g.mean.unit = u.cm
-    assert exc.value.args[0] == ("Cannot change the unit attribute directly, "
-                                 "instead change the parameter to a new quantity")
 
 
 def test_parameter_set_value():
@@ -141,13 +150,12 @@ def test_parameter_set_value():
     assert g.amplitude.unit is u.Jy
 
     # If we try setting it to a Quantity, we raise an error
-    with pytest.raises(TypeError) as exc:
+    MESSAGE = (
+        r"The .value property on parameters should be set to unitless values, not"
+        r" Quantity objects.*"
+    )
+    with pytest.raises(TypeError, match=MESSAGE):
         g.amplitude.value = 3 * u.Jy
-    assert exc.value.args[0] == \
-        ("The .value property on parameters should be set"
-         " to unitless values, not Quantity objects. To set"
-         "a parameter to a quantity simply set the "
-         "parameter directly without using .value")
 
 
 def test_parameter_quantity_property():
@@ -174,22 +182,24 @@ def test_parameter_quantity_property():
     assert g.amplitude.unit is u.s
 
     # But not to a value without units
-    with pytest.raises(TypeError) as exc:
+    MESSAGE = r"The .quantity attribute should be set to a Quantity object"
+    with pytest.raises(TypeError, match=MESSAGE):
         g.amplitude.quantity = 3
-    assert exc.value.args[0] == "The .quantity attribute should be set to a Quantity object"
 
 
 def test_parameter_default_units_match():
-
     # If the unit and default quantity units are different, raise an error
-    with pytest.raises(ParameterDefinitionError) as exc:
+    MESSAGE = (
+        r"parameter default 1.0 m does not have units equivalent to the required"
+        r" unit Jy"
+    )
+    with pytest.raises(ParameterDefinitionError, match=MESSAGE):
+
         class TestC(Fittable1DModel):
             a = Parameter(default=1.0 * u.m, unit=u.Jy)
-    assert exc.value.args[0] == ("parameter default 1.0 m does not have units "
-                                 "equivalent to the required unit Jy")
 
 
-@pytest.mark.parametrize(('unit', 'default'), ((u.m, 1.0), (None, 1 * u.m)))
+@pytest.mark.parametrize(("unit", "default"), ((u.m, 1.0), (None, 1 * u.m)))
 def test_parameter_defaults(unit, default):
     """
     Test that default quantities are correctly taken into account
@@ -234,10 +244,9 @@ def test_parameter_defaults(unit, default):
     assert m.a.default == 1.0
 
     # Instantiating with different units works, and just replaces the original unit
-    with pytest.raises(InputParameterError) as exc:
+    MESSAGE = r".* requires a Quantity for parameter .*"
+    with pytest.raises(InputParameterError, match=MESSAGE):
         TestModel(1.0)
-    assert exc.value.args[0] == ("TestModel.__init__() requires a "
-                                 "Quantity for parameter 'a'")
 
 
 def test_parameter_quantity_arithmetic():
@@ -257,26 +266,22 @@ def test_parameter_quantity_arithmetic():
     assert 2 * g.mean == (2 * u.m)
 
     # Multiplication by a quantity should result in units being multiplied
-    assert g.mean * (2 * u.m) == (2 * (u.m ** 2))
-    assert (2 * u.m) * g.mean == (2 * (u.m ** 2))
+    assert g.mean * (2 * u.m) == (2 * (u.m**2))
+    assert (2 * u.m) * g.mean == (2 * (u.m**2))
 
     # Negation should work properly too
     assert -g.mean == (-1 * u.m)
     assert abs(-g.mean) == g.mean
 
     # However, addition of a quantity + scalar should not work
-    with pytest.raises(UnitsError) as exc:
+    MESSAGE = (
+        r"Can only apply 'add' function to dimensionless quantities when other"
+        r" argument .*"
+    )
+    with pytest.raises(UnitsError, match=MESSAGE):
         g.mean + 1
-    assert exc.value.args[0] == ("Can only apply 'add' function to "
-                                 "dimensionless quantities when other argument "
-                                 "is not a quantity (unless the latter is all "
-                                 "zero/infinity/nan)")
-    with pytest.raises(UnitsError) as exc:
+    with pytest.raises(UnitsError, match=MESSAGE):
         1 + g.mean
-    assert exc.value.args[0] == ("Can only apply 'add' function to "
-                                 "dimensionless quantities when other argument "
-                                 "is not a quantity (unless the latter is all "
-                                 "zero/infinity/nan)")
 
 
 def test_parameter_quantity_comparison():
@@ -296,19 +301,15 @@ def test_parameter_quantity_comparison():
     assert g.mean < 2 * u.m
     assert 2 * u.m > g.mean
 
-    with pytest.raises(UnitsError) as exc:
-        g.mean < 2
-    assert exc.value.args[0] == ("Can only apply 'less' function to "
-                                 "dimensionless quantities when other argument "
-                                 "is not a quantity (unless the latter is all "
-                                 "zero/infinity/nan)")
+    MESSAGE = (
+        r"Can only apply 'less' function to dimensionless quantities when other"
+        r" argument .*"
+    )
+    with pytest.raises(UnitsError, match=MESSAGE):
+        g.mean < 2  # noqa: B015
 
-    with pytest.raises(UnitsError) as exc:
-        2 > g.mean
-    assert exc.value.args[0] == ("Can only apply 'less' function to "
-                                 "dimensionless quantities when other argument "
-                                 "is not a quantity (unless the latter is all "
-                                 "zero/infinity/nan)")
+    with pytest.raises(UnitsError, match=MESSAGE):
+        2 > g.mean  # noqa: B015
 
     g = Gaussian1D([1, 2] * u.J, [1, 2] * u.m, [0.1, 0.2] * u.m)
 
@@ -317,25 +318,86 @@ def test_parameter_quantity_comparison():
     assert np.all(g.mean != [1, 2])
     assert np.all([1, 2] != g.mean)
 
-    with pytest.raises(UnitsError) as exc:
-        g.mean < [3, 4]
-    assert exc.value.args[0] == ("Can only apply 'less' function to "
-                                 "dimensionless quantities when other argument "
-                                 "is not a quantity (unless the latter is all "
-                                 "zero/infinity/nan)")
+    with pytest.raises(UnitsError, match=MESSAGE):
+        g.mean < [3, 4]  # noqa: B015
 
-    with pytest.raises(UnitsError) as exc:
-        [3, 4] > g.mean
-    assert exc.value.args[0] == ("Can only apply 'less' function to "
-                                 "dimensionless quantities when other argument "
-                                 "is not a quantity (unless the latter is all "
-                                 "zero/infinity/nan)")
+    with pytest.raises(UnitsError, match=MESSAGE):
+        [3, 4] > g.mean  # noqa: B015
 
 
 def test_parameters_compound_models():
-    tan = Pix2Sky_TAN()
+    Pix2Sky_TAN()
     sky_coords = coord.SkyCoord(ra=5.6, dec=-72, unit=u.deg)
     lon_pole = 180 * u.deg
     n2c = RotateNative2Celestial(sky_coords.ra, sky_coords.dec, lon_pole)
     rot = Rotation2D(23)
-    m = rot | n2c
+    rot | n2c
+
+
+def test_magunit_parameter():
+    """Regression test for bug reproducer in issue #13133"""
+
+    unit = u.ABmag
+    c = -20.0 * unit
+    model = Const1D(c)
+
+    assert model(-23.0 * unit) == c
+
+
+def test_log_getter():
+    """Regression test for issue #14511"""
+
+    x = 6000 * u.AA
+    mdl_base = BlackBody(temperature=5000 * u.K, scale=u.Quantity(1))
+
+    class CustomBlackBody(BlackBody):
+        scale = Parameter(
+            "scale",
+            default=1,
+            bounds=(0, None),
+            getter=np.log,
+            setter=np.exp,
+            unit=u.dimensionless_unscaled,
+        )
+
+    mdl = CustomBlackBody(temperature=5000 * u.K, scale=u.Quantity(np.log(1)))
+    assert mdl.scale == np.log(1)
+    assert_quantity_allclose(mdl(x), mdl_base(x))
+
+
+def test_sqrt_getter():
+    """Regression test for issue #14511"""
+
+    x = 1 * u.m
+    mdl_base = Gaussian1D(mean=32 * u.m, stddev=3 * u.m)
+
+    class CustomGaussian1D(Gaussian1D):
+        mean = Parameter(
+            "mean",
+            default=1 * u.m,
+            bounds=(0, None),
+            getter=np.sqrt,
+            setter=np.square,
+            unit=u.m,
+        )
+        stddev = Parameter(
+            "stddev",
+            default=1 * u.m,
+            bounds=(0, None),
+            getter=np.sqrt,
+            setter=np.square,
+            unit=u.m,
+        )
+
+    mdl = CustomGaussian1D(mean=np.sqrt(32 * u.m), stddev=np.sqrt(3 * u.m))
+    assert mdl.mean == np.sqrt(32 * u.m)
+    assert (
+        mdl.mean._internal_value == np.sqrt(32) ** 2
+    )  # numerical inaccuracy results in 32.00000000000001
+    assert mdl.mean._internal_unit == u.m
+    assert mdl.stddev == np.sqrt(3 * u.m)
+    assert (
+        mdl.stddev._internal_value == np.sqrt(3) ** 2
+    )  # numerical inaccuracy results in 3.0000000000000004
+    assert mdl.stddev._internal_unit == u.m
+    assert_quantity_allclose(mdl(x), mdl_base(x))
