@@ -2,18 +2,30 @@
 # This module implements the base NDData class.
 
 
-import numpy as np
 from copy import deepcopy
 
+import numpy as np
+
+from astropy import log
+from astropy.units import Quantity, Unit
+from astropy.utils.masked import Masked, MaskedNDArray
+from astropy.utils.metadata import MetaData
+from astropy.wcs.wcsapi import (
+    BaseHighLevelWCS,
+    BaseLowLevelWCS,
+    HighLevelWCSWrapper,
+    SlicedLowLevelWCS,  # noqa: F401
+)
+
+try:
+    import dask.array as da
+except ImportError:
+    da = None
+
 from .nddata_base import NDDataBase
 from .nduncertainty import NDUncertainty, UnknownUncertainty
-from astropy import log
-from astropy.units import Unit, Quantity
-from astropy.utils.metadata import MetaData
-from astropy.wcs.wcsapi import (BaseLowLevelWCS, BaseHighLevelWCS,
-                                SlicedLowLevelWCS, HighLevelWCSWrapper)
 
-__all__ = ['NDData']
+__all__ = ["NDData"]
 
 _meta_doc = """`dict`-like : Additional meta information about the dataset."""
 
@@ -32,7 +44,7 @@ class NDData(NDDataBase):
     See also: https://docs.astropy.org/en/stable/nddata/
 
     Parameters
-    -----------
+    ----------
     data : `numpy.ndarray`-like or `NDData`-like
         The dataset.
 
@@ -75,6 +87,10 @@ class NDData(NDDataBase):
 
         .. versionadded:: 1.2
 
+    psf : `numpy.ndarray` or None, optional
+        Image representation of the PSF. In order for convolution to be flux-
+        preserving, this should generally be normalized to sum to unity.
+
     Raises
     ------
     TypeError
@@ -102,11 +118,11 @@ class NDData(NDDataBase):
         >>> nd2 = NDData(q, unit=u.cm)
         INFO: overwriting Quantity's current unit with specified unit. [astropy.nddata.nddata]
         >>> nd2.data  # doctest: +FLOAT_CMP
-        array([1., 2., 3., 4.])
+        array([100., 200., 300., 400.])
         >>> nd2.unit
         Unit("cm")
 
-    See also
+    See Also
     --------
     NDDataRef
     NDDataArray
@@ -116,9 +132,17 @@ class NDData(NDDataBase):
     # Tables. It will check if the meta is dict-like or raise an exception.
     meta = MetaData(doc=_meta_doc, copy=False)
 
-    def __init__(self, data, uncertainty=None, mask=None, wcs=None,
-                 meta=None, unit=None, copy=False):
-
+    def __init__(
+        self,
+        data,
+        uncertainty=None,
+        mask=None,
+        wcs=None,
+        meta=None,
+        unit=None,
+        copy=False,
+        psf=None,
+    ):
         # Rather pointless since the NDDataBase does not implement any setting
         # but before the NDDataBase did call the uncertainty
         # setter. But if anyone wants to alter this behavior again the call
@@ -139,72 +163,116 @@ class NDData(NDDataBase):
             # unit just overwrite the unit parameter with the NDData.unit
             # and proceed as if that one was given as parameter. Same for the
             # other parameters.
-            if (unit is not None and data.unit is not None and
-                    unit != data.unit):
-                log.info("overwriting NDData's current "
-                         "unit with specified unit.")
-            elif data.unit is not None:
+            if unit is None and data.unit is not None:
                 unit = data.unit
+            elif unit is not None and data.unit is not None:
+                log.info("overwriting NDData's current unit with specified unit.")
 
             if uncertainty is not None and data.uncertainty is not None:
-                log.info("overwriting NDData's current "
-                         "uncertainty with specified uncertainty.")
+                log.info(
+                    "overwriting NDData's current "
+                    "uncertainty with specified uncertainty."
+                )
             elif data.uncertainty is not None:
                 uncertainty = data.uncertainty
 
             if mask is not None and data.mask is not None:
-                log.info("overwriting NDData's current "
-                         "mask with specified mask.")
+                log.info("overwriting NDData's current mask with specified mask.")
             elif data.mask is not None:
                 mask = data.mask
 
             if wcs is not None and data.wcs is not None:
-                log.info("overwriting NDData's current "
-                         "wcs with specified wcs.")
+                log.info("overwriting NDData's current wcs with specified wcs.")
             elif data.wcs is not None:
                 wcs = data.wcs
 
+            if psf is not None and data.psf is not None:
+                log.info("Overwriting NDData's current psf with specified psf.")
+            elif data.psf is not None:
+                psf = data.psf
+
             if meta is not None and data.meta is not None:
-                log.info("overwriting NDData's current "
-                         "meta with specified meta.")
+                log.info("overwriting NDData's current meta with specified meta.")
             elif data.meta is not None:
                 meta = data.meta
 
+            # get the data attribute as it is, and continue to process it:
             data = data.data
 
-        else:
-            if hasattr(data, 'mask') and hasattr(data, 'data'):
-                # Separating data and mask
+        # if the data is wrapped by astropy.utils.masked.Masked:
+        if isinstance(data, Masked):
+            # first get the mask if one is available:
+            if hasattr(data, "mask"):
                 if mask is not None:
-                    log.info("overwriting Masked Objects's current "
-                             "mask with specified mask.")
+                    log.info(
+                        "overwriting Masked Quantity's current mask with specified mask."
+                    )
                 else:
                     mask = data.mask
 
-                # Just save the data for further processing, we could be given
-                # a masked Quantity or something else entirely. Better to check
-                # it first.
-                data = data.data
+            if isinstance(data, MaskedNDArray):
+                if unit is not None and hasattr(data, "unit") and data.unit != unit:
+                    log.info(
+                        "overwriting MaskedNDArray's current unit with specified unit."
+                    )
+                    data = data.to(unit).value
+                elif unit is None and hasattr(data, "unit"):
+                    unit = data.unit
+                    data = data.value
+
+                # now get the unmasked ndarray:
+                data = np.asarray(data)
 
             if isinstance(data, Quantity):
-                if unit is not None and unit != data.unit:
-                    log.info("overwriting Quantity's current "
-                             "unit with specified unit.")
-                else:
+                # this is a Quantity:
+                if unit is not None and data.unit != unit:
+                    log.info("overwriting Quantity's current unit with specified unit.")
+                    data = data.to(unit)
+                elif unit is None and data.unit is not None:
                     unit = data.unit
                 data = data.value
 
+        if isinstance(data, np.ma.masked_array):
+            if mask is not None:
+                log.info(
+                    "overwriting masked ndarray's current mask with specified mask."
+                )
+            else:
+                mask = data.mask
+            data = data.data
+
+        if isinstance(data, Quantity):
+            # this is a Quantity:
+            if unit is not None and data.unit != unit:
+                log.info("overwriting Quantity's current unit with specified unit.")
+                data = data.to(unit)
+            elif unit is None and data.unit is not None:
+                unit = data.unit
+            data = data.value
+
+        if isinstance(data, np.ndarray):
+            # check for mask from np.ma.masked_ndarray
+            if hasattr(data, "mask"):
+                if mask is not None:
+                    log.info(
+                        "overwriting masked ndarray's current mask with specified mask."
+                    )
+                else:
+                    mask = data.mask
+
         # Quick check on the parameters if they match the requirements.
-        if (not hasattr(data, 'shape') or not hasattr(data, '__getitem__') or
-                not hasattr(data, '__array__')):
+        if (
+            not hasattr(data, "shape")
+            or not hasattr(data, "__getitem__")
+            or not hasattr(data, "__array__")
+        ):
             # Data doesn't look like a numpy array, try converting it to
             # one.
             data = np.array(data, subok=True, copy=False)
-
         # Another quick check to see if what we got looks like an array
         # rather than an object (since numpy will convert a
         # non-numerical/non-string inputs to an array of objects).
-        if data.dtype == 'O':
+        if data.dtype == "O":
             raise TypeError("could not convert data to numpy array.")
 
         if unit is not None:
@@ -216,6 +284,7 @@ class NDData(NDDataBase):
             data = deepcopy(data)
             mask = deepcopy(mask)
             wcs = deepcopy(wcs)
+            psf = deepcopy(psf)
             meta = deepcopy(meta)
             uncertainty = deepcopy(uncertainty)
             # Actually - copying the unit is unnecessary but better safe
@@ -233,19 +302,52 @@ class NDData(NDDataBase):
         self._unit = unit
         # Call the setter for uncertainty to further check the uncertainty
         self.uncertainty = uncertainty
+        self.psf = psf
 
     def __str__(self):
         data = str(self.data)
-        unit = f" {self.unit}" if self.unit is not None else ''
+        unit = f" {self.unit}" if self.unit is not None else ""
 
         return data + unit
 
     def __repr__(self):
-        prefix = self.__class__.__name__ + '('
-        data = np.array2string(self.data, separator=', ', prefix=prefix)
-        unit = f", unit='{self.unit}'" if self.unit is not None else ''
+        prefix = self.__class__.__name__ + "("
+        # to support reprs for other non-ndarray `data` attributes,
+        # add more cases here:
+        is_dask = da is not None and isinstance(self.data, da.Array)
 
-        return ''.join((prefix, data, unit, ')'))
+        if (
+            isinstance(self.data, (int, float, np.ndarray))
+            or np.issubdtype(float, self.data)
+            or np.issubdtype(int, self.data)
+        ) and not is_dask:
+            # if data is an ndarray, get build a repr via Masked:
+            ma = Masked(self.data, mask=self.mask)
+            data_repr = repr(ma)
+            # strip the class name generated by Masked, and the final ")",
+            # and re-pad multi-line array outputs
+            after_first_paren = data_repr.index("(") + 1
+            old_prefix_spaces = " " * after_first_paren
+            new_prefix_spaces = " " * len(prefix)
+            data_repr = data_repr[after_first_paren:-1].replace(
+                old_prefix_spaces, new_prefix_spaces
+            )
+            unit = f", unit='{self.unit}'" if self.unit is not None else ""
+            return f"{prefix}{data_repr}{unit})"
+        else:
+            # relying on the builtin repr for objects other than ndarrays
+            # allows for compatibility with e.g. dask:
+            contents = []
+            for attr in ("data", "mask", "uncertainty", "unit"):
+                attr_data = getattr(self, attr)
+                if attr_data is not None:
+                    attr_prefix = f"\n  {attr}="
+                    attr_repr = repr(attr_data)
+                    attr_repr = attr_repr.replace(
+                        "\n", f'\n{" " * (len(attr_prefix) - 1)}'
+                    )
+                    contents.append(attr_prefix + attr_repr)
+            return prefix + ",".join(contents) + "\n)"
 
     @property
     def data(self):
@@ -285,15 +387,26 @@ class NDData(NDDataBase):
     @wcs.setter
     def wcs(self, wcs):
         if self._wcs is not None and wcs is not None:
-            raise ValueError("You can only set the wcs attribute with a WCS if no WCS is present.")
+            raise ValueError(
+                "You can only set the wcs attribute with a WCS if no WCS is present."
+            )
 
         if wcs is None or isinstance(wcs, BaseHighLevelWCS):
             self._wcs = wcs
         elif isinstance(wcs, BaseLowLevelWCS):
             self._wcs = HighLevelWCSWrapper(wcs)
         else:
-            raise TypeError("The wcs argument must implement either the high or"
-                            " low level WCS API.")
+            raise TypeError(
+                "The wcs argument must implement either the high or low level WCS API."
+            )
+
+    @property
+    def psf(self):
+        return self._psf
+
+    @psf.setter
+    def psf(self, value):
+        self._psf = value
 
     @property
     def uncertainty(self):
@@ -314,8 +427,8 @@ class NDData(NDDataBase):
             # it has an attribute 'uncertainty_type'.
             # If it does not match this requirement convert it to an unknown
             # uncertainty.
-            if not hasattr(value, 'uncertainty_type'):
-                log.info('uncertainty should have attribute uncertainty_type.')
+            if not hasattr(value, "uncertainty_type"):
+                log.info("uncertainty should have attribute uncertainty_type.")
                 value = UnknownUncertainty(value, copy=False)
 
             # If it is a subclass of NDUncertainty we must set the
