@@ -7,6 +7,7 @@ from packaging.version import Version
 
 from astropy import units as u
 from astropy.coordinates import SkyCoord
+from astropy.io import fits
 from astropy.nddata import (
     CCDData,
     Cutout2D,
@@ -167,9 +168,7 @@ def test_extract_array_even_shape_rounding():
     positions = (-0.99, -0.51, -0.5, -0.49, -0.01, 0)
     exp1 = (-99, 0)
     exp2 = (0, 1)
-    expected = [exp1,] * 6 + [
-        exp2,
-    ]
+    expected = [exp1] * 6 + [exp2]
 
     for pos, exp in zip(positions, expected):
         out = extract_array(data, shape, (pos,), mode="partial", fill_value=-99)
@@ -207,9 +206,7 @@ def test_extract_array_odd_shape_rounding():
     positions = (-0.99, -0.51, -0.5, -0.49, -0.01, 0)
     exp1 = (-99, -99, 0)
     exp2 = (-99, 0, 1)
-    expected = [exp1,] * 3 + [
-        exp2,
-    ] * 4
+    expected = [exp1] * 3 + [exp2] * 4
 
     for pos, exp in zip(positions, expected):
         out = extract_array(data, shape, (pos,), mode="partial", fill_value=-99)
@@ -218,9 +215,10 @@ def test_extract_array_odd_shape_rounding():
 
 def test_extract_array_wrong_mode():
     """Call extract_array with non-existing mode."""
-    with pytest.raises(ValueError) as e:
+    with pytest.raises(
+        ValueError, match="Valid modes are 'partial', 'trim', and 'strict'."
+    ):
         extract_array(np.arange(4), (2,), (0,), mode="full")
-    assert "Valid modes are 'partial', 'trim', and 'strict'." == str(e.value)
 
 
 def test_extract_array_1d_even():
@@ -608,3 +606,30 @@ class TestCutout2D:
         )
         assert_quantity_allclose(skycoord_original.ra, skycoord_cutout.ra)
         assert_quantity_allclose(skycoord_original.dec, skycoord_cutout.dec)
+
+
+def test_cutout_section(tmp_path):
+    # Make sure that one can pass ImageHDU.section and CompImageHDU.section
+    # to Cutout2D
+
+    data = np.ones((200, 200))
+
+    hdu = fits.ImageHDU(data=data)
+    hdu.writeto(tmp_path / "uncompressed.fits")
+
+    with fits.open(tmp_path / "uncompressed.fits") as hdul:
+        c = Cutout2D(
+            hdul[1].section,
+            (75, 75),
+            100 * u.pix,
+        )
+
+    chdu = fits.CompImageHDU(data=data)
+    chdu.writeto(tmp_path / "compressed.fits")
+
+    with fits.open(tmp_path / "compressed.fits") as hdul:
+        c = Cutout2D(
+            hdul[1].section,
+            (75, 75),
+            100 * u.pix,
+        )
