@@ -2,13 +2,12 @@
 
 import pytest
 
-from astropy.samp.hub_proxy import SAMPHubProxy
-from astropy.samp.client import SAMPClient
-from astropy.samp.integrated_client import SAMPIntegratedClient
-from astropy.samp.hub import SAMPHubServer
-
 # By default, tests should not use the internet.
-from astropy.samp import conf
+from astropy.samp import SAMPWarning, conf
+from astropy.samp.client import SAMPClient
+from astropy.samp.hub import SAMPHubServer
+from astropy.samp.hub_proxy import SAMPHubProxy
+from astropy.samp.integrated_client import SAMPIntegratedClient
 
 
 def setup_module(module):
@@ -32,11 +31,22 @@ def test_SAMPIntegratedClient():
 
 
 @pytest.fixture
-def samp_hub(request):
+def samp_hub():
     """A fixture that can be used by client tests that require a HUB."""
     my_hub = SAMPHubServer()
     my_hub.start()
-    request.addfinalizer(my_hub.stop)
+    yield
+    my_hub.stop()
+
+
+def test_SAMPIntegratedClient_notify_all(samp_hub):
+    """Test that SAMP returns a warning if no receiver got the message."""
+    client = SAMPIntegratedClient()
+    client.connect()
+    message = {"samp.mtype": "coverage.load.moc.fits"}
+    with pytest.warns(SAMPWarning):
+        client.notify_all(message)
+    client.disconnect()
 
 
 def test_reconnect(samp_hub):
