@@ -1,16 +1,22 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 """
-Methods for selecting the bin width of histograms
+Methods for selecting the bin width of histograms.
 
 Ported from the astroML project: https://www.astroml.org/
 """
 
 import numpy as np
-from . import bayesian_blocks
 
-__all__ = ['histogram', 'scott_bin_width', 'freedman_bin_width',
-           'knuth_bin_width', 'calculate_bin_edges']
+from .bayesian_blocks import bayesian_blocks
+
+__all__ = [
+    "histogram",
+    "scott_bin_width",
+    "freedman_bin_width",
+    "knuth_bin_width",
+    "calculate_bin_edges",
+]
 
 
 def calculate_bin_edges(a, bins=10, range=None, weights=None):
@@ -19,7 +25,6 @@ def calculate_bin_edges(a, bins=10, range=None, weights=None):
 
     Parameters
     ----------
-
     a : array-like
         Input data. The bin edges are calculated over the flattened array.
 
@@ -52,16 +57,17 @@ def calculate_bin_edges(a, bins=10, range=None, weights=None):
         # TODO: if weights is specified, we need to modify things.
         #       e.g. we could use point measures fitness for Bayesian blocks
         if weights is not None:
-            raise NotImplementedError("weights are not yet supported "
-                                      "for the enhanced histogram")
+            raise NotImplementedError(
+                "weights are not yet supported for the enhanced histogram"
+            )
 
-        if bins == 'blocks':
+        if bins == "blocks":
             bins = bayesian_blocks(a)
-        elif bins == 'knuth':
+        elif bins == "knuth":
             da, bins = knuth_bin_width(a, True)
-        elif bins == 'scott':
+        elif bins == "scott":
             da, bins = scott_bin_width(a, True)
-        elif bins == 'freedman':
+        elif bins == "freedman":
             da, bins = freedman_bin_width(a, True)
         else:
             raise ValueError(f"unrecognized bin code: '{bins}'")
@@ -84,12 +90,12 @@ def calculate_bin_edges(a, bins=10, range=None, weights=None):
 
 
 def histogram(a, bins=10, range=None, weights=None, **kwargs):
-    """Enhanced histogram function, providing adaptive binnings
+    """Enhanced histogram function, providing adaptive binnings.
 
     This is a histogram function that enables the use of more sophisticated
     algorithms for determining bins.  Aside from the ``bins`` argument allowing
     a string specified how bins are computed, the parameters are the same
-    as ``numpy.histogram()``.
+    as `numpy.histogram`.
 
     Parameters
     ----------
@@ -117,7 +123,8 @@ def histogram(a, bins=10, range=None, weights=None, **kwargs):
         count of values. This argument does not affect determination of bin
         edges.
 
-    other keyword arguments are described in numpy.histogram().
+    **kwargs : dict, optional
+        Extra arguments are described in `numpy.histogram`.
 
     Returns
     -------
@@ -131,14 +138,13 @@ def histogram(a, bins=10, range=None, weights=None, **kwargs):
     --------
     numpy.histogram
     """
-
     bins = calculate_bin_edges(a, bins=bins, range=range, weights=weights)
     # Now we call numpy's histogram with the resulting bin edges
     return np.histogram(a, bins=bins, range=range, weights=weights, **kwargs)
 
 
 def scott_bin_width(data, return_bins=False):
-    r"""Return the optimal histogram bin width using Scott's rule
+    r"""Return the optimal histogram bin width using Scott's rule.
 
     Scott's rule is a normal reference rule: it minimizes the integrated
     mean squared error in the bin approximation under the assumption that the
@@ -199,7 +205,7 @@ def scott_bin_width(data, return_bins=False):
 
 
 def freedman_bin_width(data, return_bins=False):
-    r"""Return the optimal histogram bin width using the Freedman-Diaconis rule
+    r"""Return the optimal histogram bin width using the Freedman-Diaconis rule.
 
     The Freedman-Diaconis rule is a normal reference rule like Scott's
     rule, but uses rank-based statistics for results which are more robust
@@ -259,12 +265,13 @@ def freedman_bin_width(data, return_bins=False):
         try:
             bins = dmin + dx * np.arange(Nbins + 1)
         except ValueError as e:
-            if 'Maximum allowed size exceeded' in str(e):
+            if "Maximum allowed size exceeded" in str(e):
                 raise ValueError(
-                    'The inter-quartile range of the data is too small: '
-                    'failed to construct histogram with {} bins. '
-                    'Please use another bin method, such as '
-                    'bins="scott"'.format(Nbins + 1))
+                    "The inter-quartile range of the data is too small: "
+                    f"failed to construct histogram with {Nbins + 1} bins. "
+                    "Please use another bin method, such as "
+                    'bins="scott"'
+                )
             else:  # Something else  # pragma: no cover
                 raise
         return dx, bins
@@ -336,7 +343,7 @@ def knuth_bin_width(data, return_bins=False, quiet=True):
 
 
 class _KnuthF:
-    r"""Class which implements the function minimized by knuth_bin_width
+    r"""Class which implements the function minimized by knuth_bin_width.
 
     Parameters
     ----------
@@ -360,6 +367,7 @@ class _KnuthF:
     --------
     knuth_bin_width
     """
+
     def __init__(self, data):
         self.data = np.array(data, copy=True)
         if self.data.ndim != 1:
@@ -376,26 +384,28 @@ class _KnuthF:
         self.gammaln = special.gammaln
 
     def bins(self, M):
-        """Return the bin edges given a width dx"""
+        """Return the bin edges given M number of bins."""
         return np.linspace(self.data[0], self.data[-1], int(M) + 1)
 
     def __call__(self, M):
         return self.eval(M)
 
     def eval(self, M):
-        """Evaluate the Knuth function
+        """Evaluate the Knuth function.
 
         Parameters
         ----------
-        dx : float
-            Width of bins
+        M : int
+            Number of bins
 
         Returns
         -------
         F : float
-            evaluation of the negative Knuth likelihood function:
+            evaluation of the negative Knuth loglikelihood function:
             smaller values indicate a better fit.
         """
+        if not np.isscalar(M):
+            M = M[0]
         M = int(M)
 
         if M <= 0:
@@ -404,8 +414,10 @@ class _KnuthF:
         bins = self.bins(M)
         nk, bins = np.histogram(self.data, bins)
 
-        return -(self.n * np.log(M) +
-                 self.gammaln(0.5 * M) -
-                 M * self.gammaln(0.5) -
-                 self.gammaln(self.n + 0.5 * M) +
-                 np.sum(self.gammaln(nk + 0.5)))
+        return -(
+            self.n * np.log(M)
+            + self.gammaln(0.5 * M)
+            - M * self.gammaln(0.5)
+            - self.gammaln(self.n + 0.5 * M)
+            + np.sum(self.gammaln(nk + 0.5))
+        )
