@@ -4,11 +4,11 @@ This module implements functions and classes for spatial statistics.
 """
 
 
-import numpy as np
 import math
 
+import numpy as np
 
-__all__ = ['RipleysKEstimator']
+__all__ = ["RipleysKEstimator"]
 
 
 class RipleysKEstimator:
@@ -74,7 +74,7 @@ class RipleysKEstimator:
         if isinstance(value, (float, int)) and value > 0:
             self._area = value
         else:
-            raise ValueError(f'area is expected to be a positive number. Got {value}.')
+            raise ValueError(f"area is expected to be a positive number. Got {value}.")
 
     @property
     def y_max(self):
@@ -85,8 +85,9 @@ class RipleysKEstimator:
         if value is None or isinstance(value, (float, int)):
             self._y_max = value
         else:
-            raise ValueError('y_max is expected to be a real number '
-                             'or None. Got {}.'.format(value))
+            raise ValueError(
+                f"y_max is expected to be a real number or None. Got {value}."
+            )
 
     @property
     def x_max(self):
@@ -97,8 +98,9 @@ class RipleysKEstimator:
         if value is None or isinstance(value, (float, int)):
             self._x_max = value
         else:
-            raise ValueError('x_max is expected to be a real number '
-                             'or None. Got {}.'.format(value))
+            raise ValueError(
+                f"x_max is expected to be a real number or None. Got {value}."
+            )
 
     @property
     def y_min(self):
@@ -109,7 +111,7 @@ class RipleysKEstimator:
         if value is None or isinstance(value, (float, int)):
             self._y_min = value
         else:
-            raise ValueError(f'y_min is expected to be a real number. Got {value}.')
+            raise ValueError(f"y_min is expected to be a real number. Got {value}.")
 
     @property
     def x_min(self):
@@ -120,9 +122,9 @@ class RipleysKEstimator:
         if value is None or isinstance(value, (float, int)):
             self._x_min = value
         else:
-            raise ValueError(f'x_min is expected to be a real number. Got {value}.')
+            raise ValueError(f"x_min is expected to be a real number. Got {value}.")
 
-    def __call__(self, data, radii, mode='none'):
+    def __call__(self, data, radii, mode="none"):
         return self.evaluate(data=data, radii=radii, mode=mode)
 
     def _pairwise_diffs(self, data):
@@ -131,7 +133,7 @@ class RipleysKEstimator:
         k = 0
         for i in range(npts - 1):
             size = npts - i - 1
-            diff[k:k + size] = abs(data[i] - data[i+1:])
+            diff[k : k + size] = abs(data[i] - data[i + 1 :])
             k += size
 
         return diff
@@ -151,26 +153,23 @@ class RipleysKEstimator:
         output : 1D array
             Ripley's K function evaluated at ``radii``.
         """
-
         return np.pi * radii * radii
 
-    def Lfunction(self, data, radii, mode='none'):
+    def Lfunction(self, data, radii, mode="none"):
         """
         Evaluates the L function at ``radii``. For parameter description
         see ``evaluate`` method.
         """
-
         return np.sqrt(self.evaluate(data, radii, mode=mode) / np.pi)
 
-    def Hfunction(self, data, radii, mode='none'):
+    def Hfunction(self, data, radii, mode="none"):
         """
         Evaluates the H function at ``radii``. For parameter description
         see ``evaluate`` method.
         """
-
         return self.Lfunction(data, radii, mode=mode) - radii
 
-    def evaluate(self, data, radii, mode='none'):
+    def evaluate(self, data, radii, mode="none"):
         """
         Evaluates the Ripley K estimator for a given set of values ``radii``.
 
@@ -219,29 +218,31 @@ class RipleysKEstimator:
         ripley : 1D array
             Ripley's K function estimator evaluated at ``radii``.
         """
-
         data = np.asarray(data)
 
         if not data.shape[1] == 2:
-            raise ValueError('data must be an n by 2 array, where n is the '
-                             'number of observed points.')
+            raise ValueError(
+                "data must be an n by 2 array, where n is the "
+                "number of observed points."
+            )
 
         npts = len(data)
         ripley = np.zeros(len(radii))
 
-        if mode == 'none':
+        if mode == "none":
             diff = self._pairwise_diffs(data)
             distances = np.hypot(diff[:, 0], diff[:, 1])
             for r in range(len(radii)):
                 ripley[r] = (distances < radii[r]).sum()
 
-            ripley = self.area * 2. * ripley / (npts * (npts - 1))
+            ripley = self.area * 2.0 * ripley / (npts * (npts - 1))
         # eq. 15.11 Stoyan book page 283
-        elif mode == 'translation':
+        elif mode == "translation":
             diff = self._pairwise_diffs(data)
             distances = np.hypot(diff[:, 0], diff[:, 1])
-            intersec_area = (((self.x_max - self.x_min) - diff[:, 0]) *
-                             ((self.y_max - self.y_min) - diff[:, 1]))
+            intersec_area = ((self.x_max - self.x_min) - diff[:, 0]) * (
+                (self.y_max - self.y_min) - diff[:, 1]
+            )
 
             for r in range(len(radii)):
                 dist_indicator = distances < radii[r]
@@ -249,24 +250,35 @@ class RipleysKEstimator:
 
             ripley = (self.area**2 / (npts * (npts - 1))) * 2 * ripley
         # Stoyan book page 123 and eq 15.13
-        elif mode == 'ohser':
+        elif mode == "ohser":
             diff = self._pairwise_diffs(data)
             distances = np.hypot(diff[:, 0], diff[:, 1])
             a = self.area
-            b = max((self.y_max - self.y_min) / (self.x_max - self.x_min),
-                    (self.x_max - self.x_min) / (self.y_max - self.y_min))
+            b = max(
+                (self.y_max - self.y_min) / (self.x_max - self.x_min),
+                (self.x_max - self.x_min) / (self.y_max - self.y_min),
+            )
             x = distances / math.sqrt(a / b)
             u = np.sqrt((x * x - 1) * (x > 1))
-            v = np.sqrt((x * x - b ** 2) * (x < math.sqrt(b ** 2 + 1)) * (x > b))
+            v = np.sqrt((x * x - b**2) * (x < math.sqrt(b**2 + 1)) * (x > b))
             c1 = np.pi - 2 * x * (1 + 1 / b) + x * x / b
             c2 = 2 * np.arcsin((1 / x) * (x > 1)) - 1 / b - 2 * (x - u)
-            c3 = (2 * np.arcsin(((b - u * v) / (x * x))
-                                * (x > b) * (x < math.sqrt(b ** 2 + 1)))
-                  + 2 * u + 2 * v / b - b - (1 + x * x) / b)
+            c3 = (
+                2
+                * np.arcsin(
+                    ((b - u * v) / (x * x)) * (x > b) * (x < math.sqrt(b**2 + 1))
+                )
+                + 2 * u
+                + 2 * v / b
+                - b
+                - (1 + x * x) / b
+            )
 
-            cov_func = ((a / np.pi) * (c1 * (x >= 0) * (x <= 1)
-                        + c2 * (x > 1) * (x <= b)
-                        + c3 * (b < x) * (x < math.sqrt(b ** 2 + 1))))
+            cov_func = (a / np.pi) * (
+                c1 * (x >= 0) * (x <= 1)
+                + c2 * (x > 1) * (x <= b)
+                + c3 * (b < x) * (x < math.sqrt(b**2 + 1))
+            )
 
             for r in range(len(radii)):
                 dist_indicator = distances < radii[r]
@@ -274,9 +286,11 @@ class RipleysKEstimator:
 
             ripley = (self.area**2 / (npts * (npts - 1))) * 2 * ripley
         # Cressie book eq 8.2.20 page 616
-        elif mode == 'var-width':
-            lt_dist = np.minimum(np.minimum(self.x_max - data[:, 0], self.y_max - data[:, 1]),
-                                 np.minimum(data[:, 0] - self.x_min, data[:, 1] - self.y_min))
+        elif mode == "var-width":
+            lt_dist = np.minimum(
+                np.minimum(self.x_max - data[:, 0], self.y_max - data[:, 1]),
+                np.minimum(data[:, 0] - self.x_min, data[:, 1] - self.y_min),
+            )
 
             for r in range(len(radii)):
                 for i in range(npts):
@@ -292,39 +306,47 @@ class RipleysKEstimator:
 
             ripley = self.area * ripley / npts
         # Cressie book eq 8.4.22 page 640
-        elif mode == 'ripley':
-            hor_dist = np.zeros(shape=(npts * (npts - 1)) // 2,
-                                dtype=np.double)
-            ver_dist = np.zeros(shape=(npts * (npts - 1)) // 2,
-                                dtype=np.double)
+        elif mode == "ripley":
+            hor_dist = np.zeros(shape=(npts * (npts - 1)) // 2, dtype=np.double)
+            ver_dist = np.zeros(shape=(npts * (npts - 1)) // 2, dtype=np.double)
 
             for k in range(npts - 1):
-                min_hor_dist = min(self.x_max - data[k][0],
-                                   data[k][0] - self.x_min)
-                min_ver_dist = min(self.y_max - data[k][1],
-                                   data[k][1] - self.y_min)
+                min_hor_dist = min(self.x_max - data[k][0], data[k][0] - self.x_min)
+                min_ver_dist = min(self.y_max - data[k][1], data[k][1] - self.y_min)
                 start = (k * (2 * (npts - 1) - (k - 1))) // 2
                 end = ((k + 1) * (2 * (npts - 1) - k)) // 2
-                hor_dist[start: end] = min_hor_dist * np.ones(npts - 1 - k)
-                ver_dist[start: end] = min_ver_dist * np.ones(npts - 1 - k)
+                hor_dist[start:end] = min_hor_dist * np.ones(npts - 1 - k)
+                ver_dist[start:end] = min_ver_dist * np.ones(npts - 1 - k)
 
             diff = self._pairwise_diffs(data)
             dist = np.hypot(diff[:, 0], diff[:, 1])
             dist_ind = dist <= np.hypot(hor_dist, ver_dist)
 
-            w1 = (1 - (np.arccos(np.minimum(ver_dist, dist) / dist) +
-                       np.arccos(np.minimum(hor_dist, dist) / dist)) / np.pi)
-            w2 = (3 / 4 - 0.5 * (
-                np.arccos(ver_dist / dist * ~dist_ind) +
-                np.arccos(hor_dist / dist * ~dist_ind)) / np.pi)
+            w1 = (
+                1
+                - (
+                    np.arccos(np.minimum(ver_dist, dist) / dist)
+                    + np.arccos(np.minimum(hor_dist, dist) / dist)
+                )
+                / np.pi
+            )
+            w2 = (
+                3 / 4
+                - 0.5
+                * (
+                    np.arccos(ver_dist / dist * ~dist_ind)
+                    + np.arccos(hor_dist / dist * ~dist_ind)
+                )
+                / np.pi
+            )
 
             weight = dist_ind * w1 + ~dist_ind * w2
 
             for r in range(len(radii)):
                 ripley[r] = ((dist < radii[r]) / weight).sum()
 
-            ripley = self.area * 2. * ripley / (npts * (npts - 1))
+            ripley = self.area * 2.0 * ripley / (npts * (npts - 1))
         else:
-            raise ValueError(f'mode {mode} is not implemented.')
+            raise ValueError(f"mode {mode} is not implemented.")
 
         return ripley
