@@ -29,16 +29,35 @@ __construct_mixin_classes = (
     "astropy.units.function.logarithmic.Magnitude",
     "astropy.units.function.logarithmic.Decibel",
     "astropy.units.function.logarithmic.Dex",
-    "astropy.coordinates.angles.Latitude",
-    "astropy.coordinates.angles.Longitude",
-    "astropy.coordinates.angles.Angle",
     "astropy.coordinates.distances.Distance",
     "astropy.coordinates.earth.EarthLocation",
     "astropy.coordinates.sky_coordinate.SkyCoord",
+    "astropy.coordinates.polarization.StokesCoord",
     "astropy.table.ndarray_mixin.NdarrayMixin",
     "astropy.table.table_helpers.ArrayWrapper",
     "astropy.table.column.Column",
     "astropy.table.column.MaskedColumn",
+    "astropy.utils.masked.core.MaskedNDArray",
+    # Angles
+    "astropy.coordinates.angles.core.Latitude",
+    "astropy.coordinates.angles.core.Longitude",
+    "astropy.coordinates.angles.core.Angle",
+    # Representations
+    "astropy.coordinates.representation.cartesian.CartesianRepresentation",
+    "astropy.coordinates.representation.spherical.UnitSphericalRepresentation",
+    "astropy.coordinates.representation.spherical.RadialRepresentation",
+    "astropy.coordinates.representation.spherical.SphericalRepresentation",
+    "astropy.coordinates.representation.spherical.PhysicsSphericalRepresentation",
+    "astropy.coordinates.representation.cylindrical.CylindricalRepresentation",
+    "astropy.coordinates.representation.cartesian.CartesianDifferential",
+    "astropy.coordinates.representation.spherical.UnitSphericalDifferential",
+    "astropy.coordinates.representation.spherical.SphericalDifferential",
+    "astropy.coordinates.representation.spherical.UnitSphericalCosLatDifferential",
+    "astropy.coordinates.representation.spherical.SphericalCosLatDifferential",
+    "astropy.coordinates.representation.spherical.RadialDifferential",
+    "astropy.coordinates.representation.spherical.PhysicsSphericalDifferential",
+    "astropy.coordinates.representation.cylindrical.CylindricalDifferential",
+    # Deprecated paths
     "astropy.coordinates.representation.CartesianRepresentation",
     "astropy.coordinates.representation.UnitSphericalRepresentation",
     "astropy.coordinates.representation.RadialRepresentation",
@@ -53,7 +72,9 @@ __construct_mixin_classes = (
     "astropy.coordinates.representation.RadialDifferential",
     "astropy.coordinates.representation.PhysicsSphericalDifferential",
     "astropy.coordinates.representation.CylindricalDifferential",
-    "astropy.utils.masked.core.MaskedNDArray",
+    "astropy.coordinates.angles.Latitude",
+    "astropy.coordinates.angles.Longitude",
+    "astropy.coordinates.angles.Angle",
 )
 
 
