@@ -1,9 +1,9 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 import os
-from setuptools import Extension
 
 import numpy
+from setuptools import Extension
 
 ROOT = os.path.relpath(os.path.dirname(__file__))
 
@@ -13,9 +13,12 @@ def get_extensions():
     include_dirs = [numpy.get_include()]
 
     exts = [
-        Extension(name='astropy.table.' + os.path.splitext(source)[0],
-                  sources=[os.path.join(ROOT, source)],
-                  include_dirs=include_dirs)
+        Extension(
+            name="astropy.table." + os.path.splitext(source)[0],
+            define_macros=[("NPY_NO_DEPRECATED_API", "NPY_1_7_API_VERSION")],
+            sources=[os.path.join(ROOT, source)],
+            include_dirs=include_dirs,
+        )
         for source in sources
     ]
 
