@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
+import re
 from collections import OrderedDict
 from contextlib import nullcontext
 
@@ -13,6 +14,7 @@ from astropy.coordinates import (
     CartesianRepresentation,
     SkyCoord,
     SphericalRepresentation,
+    StokesCoord,
     UnitSphericalRepresentation,
     search_around_3d,
 )
@@ -44,7 +46,7 @@ def check_mask(col, exp_mask):
         # With no mask the check is OK if all the expected mask values
         # are False (i.e. no auto-conversion to MaskedQuantity if it was
         # not required by the join).
-        out = np.all(exp_mask == False)
+        out = np.all(exp_mask == False)  # noqa: E712
     return out
 
 
@@ -127,10 +129,10 @@ class TestJoin:
         # Basic join with default parameters (inner join on common keys)
         t12 = table.join(t1, t2)
         assert type(t12) is operation_table_type
-        assert type(t12["a"]) is type(t1["a"])  # noqa: E721
-        assert type(t12["b"]) is type(t1["b"])  # noqa: E721
-        assert type(t12["c"]) is type(t1["c"])  # noqa: E721
-        assert type(t12["d"]) is type(t2["d"])  # noqa: E721
+        assert type(t12["a"]) is type(t1["a"])
+        assert type(t12["b"]) is type(t1["b"])
+        assert type(t12["c"]) is type(t1["c"])
+        assert type(t12["d"]) is type(t2["d"])
         assert t12.masked is False
         assert sort_eq(
             t12.pformat(),
@@ -219,11 +221,11 @@ class TestJoin:
         # Inner join on 'a' column
         t12 = table.join(t1, t2, keys="a")
         assert type(t12) is operation_table_type
-        assert type(t12["a"]) is type(t1["a"])  # noqa: E721
-        assert type(t12["b_1"]) is type(t1["b"])  # noqa: E721
-        assert type(t12["c"]) is type(t1["c"])  # noqa: E721
-        assert type(t12["b_2"]) is type(t2["b"])  # noqa: E721
-        assert type(t12["d"]) is type(t2["d"])  # noqa: E721
+        assert type(t12["a"]) is type(t1["a"])
+        assert type(t12["b_1"]) is type(t1["b"])
+        assert type(t12["c"]) is type(t1["c"])
+        assert type(t12["b_2"]) is type(t2["b"])
+        assert type(t12["d"]) is type(t2["d"])
         assert t12.masked is False
         assert sort_eq(
             t12.pformat(),
@@ -969,16 +971,16 @@ class TestSetdiff:
     def test_default_same_columns(self, operation_table_type):
         self._setup(operation_table_type)
         out = table.setdiff(self.t1, self.t2)
-        assert type(out["a"]) is type(self.t1["a"])  # noqa: E721
-        assert type(out["b"]) is type(self.t1["b"])  # noqa: E721
+        assert type(out["a"]) is type(self.t1["a"])
+        assert type(out["b"]) is type(self.t1["b"])
         assert out.pformat() == [" a   b ", "--- ---", "  1 bar", "  1 foo"]
 
     def test_default_same_tables(self, operation_table_type):
         self._setup(operation_table_type)
         out = table.setdiff(self.t1, self.t1)
 
-        assert type(out["a"]) is type(self.t1["a"])  # noqa: E721
-        assert type(out["b"]) is type(self.t1["b"])  # noqa: E721
+        assert type(out["a"]) is type(self.t1["a"])
+        assert type(out["b"]) is type(self.t1["b"])
         assert out.pformat() == [
             " a   b ",
             "--- ---",
@@ -994,8 +996,8 @@ class TestSetdiff:
         self._setup(operation_table_type)
         out = table.setdiff(self.t1, self.t3)
 
-        assert type(out["a"]) is type(self.t1["a"])  # noqa: E721
-        assert type(out["b"]) is type(self.t1["b"])  # noqa: E721
+        assert type(out["a"]) is type(self.t1["a"])
+        assert type(out["b"]) is type(self.t1["b"])
         assert out.pformat() == [
             " a   b ",
             "--- ---",
@@ -1007,8 +1009,8 @@ class TestSetdiff:
         self._setup(operation_table_type)
         out = table.setdiff(self.t3, self.t1, keys=["a", "b"])
 
-        assert type(out["a"]) is type(self.t1["a"])  # noqa: E721
-        assert type(out["b"]) is type(self.t1["b"])  # noqa: E721
+        assert type(out["a"]) is type(self.t1["a"])
+        assert type(out["b"]) is type(self.t1["b"])
         assert out.pformat() == [
             " a   b   d ",
             "--- --- ---",
@@ -1081,8 +1083,8 @@ class TestVStack:
         t2 = self.t1.copy()
         t2.meta.clear()
         out = table.vstack([self.t1, t2[1]])
-        assert type(out["a"]) is type(self.t1["a"])  # noqa: E721
-        assert type(out["b"]) is type(self.t1["b"])  # noqa: E721
+        assert type(out["a"]) is type(self.t1["a"])
+        assert type(out["b"]) is type(self.t1["b"])
         assert out.pformat() == [
             " a   b ",
             "--- ---",
@@ -1164,8 +1166,8 @@ class TestVStack:
         t12 = table.vstack([t1, t2], join_type="inner")
         assert t12.masked is False
         assert type(t12) is operation_table_type
-        assert type(t12["a"]) is type(t1["a"])  # noqa: E721
-        assert type(t12["b"]) is type(t1["b"])  # noqa: E721
+        assert type(t12["a"]) is type(t1["a"])
+        assert type(t12["b"]) is type(t1["b"])
         assert t12.pformat() == [
             " a   b ",
             "--- ---",
@@ -1177,8 +1179,8 @@ class TestVStack:
 
         t124 = table.vstack([t1, t2, t4], join_type="inner")
         assert type(t124) is operation_table_type
-        assert type(t12["a"]) is type(t1["a"])  # noqa: E721
-        assert type(t12["b"]) is type(t1["b"])  # noqa: E721
+        assert type(t12["a"]) is type(t1["a"])
+        assert type(t12["b"]) is type(t1["b"])
         assert t124.pformat() == [
             " a   b ",
             "--- ---",
@@ -1441,6 +1443,7 @@ class TestVStack:
                 SkyCoord,
                 EarthLocation,
                 BaseRepresentationOrDifferential,
+                StokesCoord,
             ),
         ):
             out = table.vstack([t, t])
@@ -1456,11 +1459,9 @@ class TestVStack:
                 assert np.all(out["a"][:len_col] == col)
                 assert np.all(out["a"][len_col:] == col)
         else:
-            with pytest.raises(NotImplementedError) as err:
+            msg = f"vstack unavailable for mixin column type(s): {cls_name}"
+            with pytest.raises(NotImplementedError, match=re.escape(msg)):
                 table.vstack([t, t])
-            assert "vstack unavailable for mixin column type(s): {}".format(
-                cls_name
-            ) in str(err.value)
 
         # Check for outer stack which requires masking.  Only Time supports
         # this currently.
@@ -1596,7 +1597,7 @@ class TestDStack:
     @staticmethod
     def compare_dstack(tables, out):
         for ii, tbl in enumerate(tables):
-            for name, out_col in out.columns.items():
+            for name in out.columns:
                 if name in tbl.colnames:
                     # Columns always compare equal
                     assert np.all(tbl[name] == out[name][:, ii])
@@ -1632,15 +1633,15 @@ class TestDStack:
         # Test for non-masked table
         t12 = table.dstack([t1, t2], join_type="outer")
         assert type(t12) is operation_table_type
-        assert type(t12["a"]) is type(t1["a"])  # noqa: E721
-        assert type(t12["b"]) is type(t1["b"])  # noqa: E721
+        assert type(t12["a"]) is type(t1["a"])
+        assert type(t12["b"]) is type(t1["b"])
         self.compare_dstack([t1, t2], t12)
 
         # Test for masked table
         t124 = table.dstack([t1, t2, t4], join_type="outer")
         assert type(t124) is operation_table_type
-        assert type(t124["a"]) is type(t4["a"])  # noqa: E721
-        assert type(t124["b"]) is type(t4["b"])  # noqa: E721
+        assert type(t124["a"]) is type(t4["a"])
+        assert type(t124["b"]) is type(t4["b"])
         self.compare_dstack([t1, t2, t4], t124)
 
     def test_dstack_basic_inner(self, operation_table_type):
@@ -1652,8 +1653,8 @@ class TestDStack:
         # Test for masked table
         t124 = table.dstack([t1, t2, t4], join_type="inner")
         assert type(t124) is operation_table_type
-        assert type(t124["a"]) is type(t4["a"])  # noqa: E721
-        assert type(t124["b"]) is type(t4["b"])  # noqa: E721
+        assert type(t124["a"]) is type(t4["a"])
+        assert type(t124["b"]) is type(t4["b"])
         self.compare_dstack([t1, t2, t4], t124)
 
     def test_dstack_multi_dimension_column(self, operation_table_type):
@@ -1663,8 +1664,8 @@ class TestDStack:
         t2 = self.t2
         t35 = table.dstack([t3, t5])
         assert type(t35) is operation_table_type
-        assert type(t35["a"]) is type(t3["a"])  # noqa: E721
-        assert type(t35["b"]) is type(t3["b"])  # noqa: E721
+        assert type(t35["a"]) is type(t3["a"])
+        assert type(t35["b"]) is type(t3["b"])
         self.compare_dstack([t3, t5], t35)
 
         with pytest.raises(TableMergeError):
@@ -1819,9 +1820,9 @@ class TestHStack:
     def test_stack_columns(self, operation_table_type):
         self._setup(operation_table_type)
         out = table.hstack([self.t1, self.t2["c"]])
-        assert type(out["a"]) is type(self.t1["a"])  # noqa: E721
-        assert type(out["b"]) is type(self.t1["b"])  # noqa: E721
-        assert type(out["c"]) is type(self.t2["c"])  # noqa: E721
+        assert type(out["a"]) is type(self.t1["a"])
+        assert type(out["b"]) is type(self.t1["b"])
+        assert type(out["c"]) is type(self.t2["c"])
         assert out.pformat() == [
             " a   b   c ",
             "--- --- ---",
@@ -1888,10 +1889,10 @@ class TestHStack:
         out = table.hstack([t1, t2], join_type="inner")
         assert out.masked is False
         assert type(out) is operation_table_type
-        assert type(out["a_1"]) is type(t1["a"])  # noqa: E721
-        assert type(out["b_1"]) is type(t1["b"])  # noqa: E721
-        assert type(out["a_2"]) is type(t2["a"])  # noqa: E721
-        assert type(out["b_2"]) is type(t2["b"])  # noqa: E721
+        assert type(out["a_1"]) is type(t1["a"])
+        assert type(out["b_1"]) is type(t1["b"])
+        assert type(out["a_2"]) is type(t2["a"])
+        assert type(out["b_2"]) is type(t2["b"])
         assert out.pformat() == [
             "a_1 b_1 a_2 b_2  c ",
             "--- --- --- --- ---",
@@ -2015,7 +2016,7 @@ class TestHStack:
         cls_name = type(col1).__name__
 
         out = table.hstack([t1, t2], join_type="inner")
-        assert type(out["col0_1"]) is type(out["col0_2"])  # noqa: E721
+        assert type(out["col0_1"]) is type(out["col0_2"])
         assert len(out) == len(col2)
 
         # Check that columns are as expected.
