@@ -1,4 +1,4 @@
-"""Main Lomb-Scargle Implementation"""
+"""Main Lomb-Scargle Implementation."""
 
 import numpy as np
 
@@ -397,7 +397,6 @@ class LombScargle(BasePeriodogram):
         current _tstart value. If the times provided are relative, they are
         returned without conversion (though we still do some checks).
         """
-
         if isinstance(times, TimeDelta):
             times = times.to("day")
 
@@ -458,7 +457,7 @@ class LombScargle(BasePeriodogram):
         return y_fit * get_unit(self.y)
 
     def offset(self):
-        """Return the offset of the model
+        """Return the offset of the model.
 
         The offset of the model is the (weighted) mean of the y values.
         Note that if self.center_data is False, the offset is 0 by definition.
@@ -527,7 +526,7 @@ class LombScargle(BasePeriodogram):
         return parameters
 
     def design_matrix(self, frequency, t=None):
-        """Compute the design matrix for a given frequency
+        """Compute the design matrix for a given frequency.
 
         Parameters
         ----------
