@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """A set of standard astronomical equivalencies."""
 
-import warnings
 from collections import UserList
 
 # THIRD-PARTY
@@ -9,7 +8,6 @@ import numpy as np
 
 # LOCAL
 from astropy.constants import si as _si
-from astropy.utils.exceptions import AstropyDeprecationWarning
 from astropy.utils.misc import isiterable
 
 from . import astrophys, cgs, dimensionless_unscaled, misc, si
@@ -84,7 +82,7 @@ def dimensionless_angles():
 
 
 def logarithmic():
-    """Allow logarithmic units to be converted to dimensionless fractions"""
+    """Allow logarithmic units to be converted to dimensionless fractions."""
     return Equivalency(
         [(dimensionless_unscaled, function_units.dex, np.log10, lambda x: 10.0**x)],
         "logarithmic",
@@ -351,7 +349,6 @@ def doppler_radio(rest):
     >>> radio_velocity  # doctest: +FLOAT_CMP
     <Quantity -31.209092088877583 km / s>
     """
-
     assert_is_spectral_unit(rest)
 
     ckms = _si.c.to_value("km/s")
@@ -421,7 +418,6 @@ def doppler_optical(rest):
     >>> optical_velocity  # doctest: +FLOAT_CMP
     <Quantity -31.20584348799674 km / s>
     """
-
     assert_is_spectral_unit(rest)
 
     ckms = _si.c.to_value("km/s")
@@ -498,8 +494,7 @@ def doppler_relativistic(rest):
     >>> relativistic_wavelength = measured_velocity.to(u.mm, equivalencies=relativistic_CO_equiv)
     >>> relativistic_wavelength  # doctest: +FLOAT_CMP
     <Quantity 2.6116243681798923 mm>
-    """  # noqa: E501
-
+    """
     assert_is_spectral_unit(rest)
 
     ckms = _si.c.to_value("km/s")
@@ -649,20 +644,7 @@ def brightness_temperature(frequency, beam_area=None):
         >>> surf_brightness = 1e6*u.MJy/u.sr
         >>> surf_brightness.to(u.K, equivalencies=u.brightness_temperature(500*u.GHz)) # doctest: +FLOAT_CMP
         <Quantity 130.1931904778803 K>
-    """  # noqa: E501
-    if frequency.unit.is_equivalent(si.sr):
-        if not beam_area.unit.is_equivalent(si.Hz):
-            raise ValueError(
-                "The inputs to `brightness_temperature` are frequency and angular area."
-            )
-        warnings.warn(
-            "The inputs to `brightness_temperature` have changed. "
-            "Frequency is now the first input, and angular area "
-            "is the second, optional input.",
-            AstropyDeprecationWarning,
-        )
-        frequency, beam_area = beam_area, frequency
-
+    """
     nu = frequency.to(si.GHz, spectral())
     factor_Jy = (2 * _si.k_B * si.K * nu**2 / _si.c**2).to(astrophys.Jy).value
     factor_K = (astrophys.Jy / (2 * _si.k_B * nu**2 / _si.c**2)).to(si.K).value
@@ -726,7 +708,7 @@ def beam_angular_area(beam_area):
 def thermodynamic_temperature(frequency, T_cmb=None):
     r"""Defines the conversion between Jy/sr and "thermodynamic temperature",
     :math:`T_{CMB}`, in Kelvins.  The thermodynamic temperature is a unit very
-    commonly used in cosmology. See eqn 8 in [1]
+    commonly used in cosmology. See eqn 8 in [1].
 
     :math:`K_{CMB} \equiv I_\nu / \left(2 k \nu^2 / c^2  f(\nu) \right)`
 
@@ -847,7 +829,6 @@ def pixel_scale(pixscale):
     pixscale : `~astropy.units.Quantity`
         The pixel scale either in units of <unit>/pixel or pixel/<unit>.
     """
-
     decomposed = pixscale.unit.decompose()
     dimensions = dict(zip(decomposed.bases, decomposed.powers))
     pix_power = dimensions.get(misc.pix, 0)
@@ -888,25 +869,3 @@ def plate_scale(platescale):
         "plate_scale",
         {"platescale": platescale},
     )
-
-
-# -------------------------------------------------------------------------
-
-
-def __getattr__(attr):
-    if attr == "with_H0":
-        import warnings
-
-        from astropy.cosmology.units import with_H0
-        from astropy.utils.exceptions import AstropyDeprecationWarning
-
-        warnings.warn(
-            "`with_H0` is deprecated from `astropy.units.equivalencies` "
-            "since astropy 5.0 and may be removed in a future version. "
-            "Use `astropy.cosmology.units.with_H0` instead.",
-            AstropyDeprecationWarning,
-        )
-
-        return with_H0
-
-    raise AttributeError(f"module {__name__!r} has no attribute {attr!r}.")
