@@ -9,13 +9,26 @@ celestial-to-terrestrial coordinate transformations
 (in `astropy.coordinates`).
 """
 
+import os
 import re
-from datetime import datetime
+from datetime import datetime, timezone
 from urllib.parse import urlparse
 from warnings import warn
 
 import erfa
 import numpy as np
+from astropy_iers_data import (
+    IERS_A_FILE,
+    IERS_A_README,
+    IERS_A_URL,
+    IERS_A_URL_MIRROR,
+    IERS_B_FILE,
+    IERS_B_README,
+    IERS_B_URL,
+    IERS_LEAP_SECOND_FILE,
+    IERS_LEAP_SECOND_URL,
+)
+from astropy_iers_data import IERS_LEAP_SECOND_URL_MIRROR as IETF_LEAP_SECOND_URL
 
 from astropy import config as _config
 from astropy import units as u
@@ -24,11 +37,10 @@ from astropy.table import MaskedColumn, QTable
 from astropy.time import Time, TimeDelta
 from astropy.utils.data import (
     clear_download_cache,
-    get_pkg_data_filename,
     get_readable_fileobj,
     is_url_in_cache,
 )
-from astropy.utils.exceptions import AstropyWarning
+from astropy.utils.exceptions import AstropyDeprecationWarning, AstropyWarning
 from astropy.utils.state import ScienceState
 
 __all__ = [
@@ -61,22 +73,6 @@ __all__ = [
     "IETF_LEAP_SECOND_URL",
 ]
 
-# IERS-A default file name, URL, and ReadMe with content description
-IERS_A_FILE = "finals2000A.all"
-IERS_A_URL = "https://datacenter.iers.org/data/9/finals2000A.all"
-IERS_A_URL_MIRROR = "https://maia.usno.navy.mil/ser7/finals2000A.all"
-IERS_A_README = get_pkg_data_filename("data/ReadMe.finals2000A")
-
-# IERS-B default file name, URL, and ReadMe with content description
-IERS_B_FILE = get_pkg_data_filename("data/eopc04.1962-now")
-IERS_B_URL = "https://hpiers.obspm.fr/iers/eop/eopc04/eopc04.1962-now"
-IERS_B_README = get_pkg_data_filename("data/ReadMe.eopc04")
-
-# LEAP SECONDS default file name, URL, and alternative format/URL
-IERS_LEAP_SECOND_FILE = get_pkg_data_filename("data/Leap_Second.dat")
-IERS_LEAP_SECOND_URL = "https://hpiers.obspm.fr/iers/bul/bulc/Leap_Second.dat"
-IETF_LEAP_SECOND_URL = "https://www.ietf.org/timezones/data/leap-seconds.list"
-
 # Status/source values returned by IERS.ut1_utc
 FROM_IERS_B = 0
 FROM_IERS_A = 1
@@ -626,7 +622,25 @@ class IERS_A(IERS):
         ``IERS_A`` class instance
         """
         if file is None:
-            file = IERS_A_FILE
+            # In prior versions of astropy, read() would only work without a
+            # file argument if a finals2000A.all file was present in the
+            # current working directory. We can now use the versions from
+            # astropy-iers-data but for backward-compatibility we first check
+            # if there is a file in the current working directory and use that
+            # if so, emitting a deprecation warning
+            if os.path.exists("finals2000A.all"):
+                file = "finals2000A.all"
+                warn(
+                    "The file= argument was not specified but "
+                    "'finals2000A.all' is present in the current working "
+                    "directory, so reading IERS data from that file. To "
+                    "continue reading a local file from the current working "
+                    "directory, specify file= explicitly otherwise a bundled "
+                    "file will be used in future.",
+                    AstropyDeprecationWarning,
+                )
+            else:
+                file = IERS_A_FILE
         if readme is None:
             readme = IERS_A_README
 
@@ -1077,7 +1091,9 @@ class LeapSeconds(QTable):
     def _today():
         # Get current day in scale='tai' without going through a scale change
         # (so we do not need leap seconds).
-        s = "{0.year:04d}-{0.month:02d}-{0.day:02d}".format(datetime.utcnow())
+        s = "{0.year:04d}-{0.month:02d}-{0.day:02d}".format(
+            datetime.now(tz=timezone.utc)
+        )
         return Time(s, scale="tai", format="iso", out_subfmt="date")
 
     @classmethod
