@@ -19,15 +19,16 @@ import urllib.parse
 import urllib.request
 import warnings
 from concurrent.futures import ThreadPoolExecutor
+from contextlib import nullcontext
 from itertools import islice
 from tempfile import NamedTemporaryFile, TemporaryDirectory
 
-import py.path
 import pytest
 
 import astropy.utils.data
 from astropy import units as _u  # u is taken
 from astropy.config import paths
+from astropy.tests.helper import CI, IS_CRON, PYTEST_LT_8_0
 from astropy.utils.data import (
     CacheDamaged,
     CacheMissingWarning,
@@ -59,7 +60,6 @@ from astropy.utils.data import (
 )
 from astropy.utils.exceptions import AstropyWarning
 
-CI = os.environ.get("CI", "false") == "true"
 TESTURL = "http://www.astropy.org"
 TESTURL2 = "http://www.astropy.org/about.html"
 TESTURL_SSL = "https://www.astropy.org"
@@ -108,7 +108,7 @@ def valid_urls(tmp_path):
     def _valid_urls(tmp_path):
         for i in itertools.count():
             c = os.urandom(16).hex()
-            fn = tmp_path / f"valid_{str(i)}"
+            fn = tmp_path / f"valid_{i}"
             with open(fn, "w") as f:
                 f.write(c)
             u = url_to(fn)
@@ -121,7 +121,7 @@ def valid_urls(tmp_path):
 def invalid_urls(tmp_path):
     def _invalid_urls(tmp_path):
         for i in itertools.count():
-            fn = tmp_path / f"invalid_{str(i)}"
+            fn = tmp_path / f"invalid_{i}"
             if not os.path.exists(fn):
                 yield url_to(fn)
 
@@ -233,7 +233,7 @@ def test_download_file_absolute_path(valid_urls, temp_cache):
     assert is_abs(download_file(u, cache=False))  # no cache
     assert is_abs(download_file(u, cache=True))  # not in cache
     assert is_abs(download_file(u, cache=True))  # in cache
-    for k, v in cache_contents().items():
+    for v in cache_contents().values():
         assert is_abs(v)
 
 
@@ -350,10 +350,8 @@ def test_download_with_sources_and_bogus_original(
     # it was loaded by mistake.
     for i, (um, c_bad) in enumerate(islice(valid_urls, FEW)):
         assert not is_url_in_cache(um)
-        sources[um] = []
         # For many of them the sources list starts with invalid URLs
-        for iu in islice(invalid_urls, i):
-            sources[um].append(iu)
+        sources[um] = list(islice(invalid_urls, i))
         u, c = next(valid_urls)
         sources[um].append(u)
         urls.append((um, c, c_bad))
@@ -390,8 +388,8 @@ def test_download_file_threaded_many(temp_cache, valid_urls):
         r = list(P.map(lambda u: download_file(u, cache=True), [u for (u, c) in urls]))
     check_download_cache()
     assert len(r) == len(urls)
-    for r, (u, c) in zip(r, urls):
-        assert get_file_contents(r) == c
+    for r_, (u, c) in zip(r, urls):
+        assert get_file_contents(r_) == c
 
 
 @pytest.mark.skipif(
@@ -442,11 +440,11 @@ def test_download_file_threaded_many_partial_success(
         r = list(P.map(get, urls))
     check_download_cache()
     assert len(r) == len(urls)
-    for r, u in zip(r, urls):
+    for r_, u in zip(r, urls):
         if u in contents:
-            assert get_file_contents(r) == contents[u]
+            assert get_file_contents(r_) == contents[u]
         else:
-            assert r is None
+            assert r_ is None
 
 
 def test_clear_download_cache(valid_urls):
@@ -688,7 +686,7 @@ def test_download_parallel_from_internet_works(temp_cache):
         urls.append(main_url + s)
         sources[urls[-1]] = [urls[-1], mirror_url + s]
     fnout = download_files_in_parallel(urls, sources=sources)
-    assert all([os.path.isfile(f) for f in fnout]), fnout
+    assert all(os.path.isfile(f) for f in fnout), fnout
 
 
 @pytest.mark.parametrize("method", [None, "spawn"])
@@ -736,9 +734,7 @@ def test_download_parallel_with_sources_and_bogus_original(
     sources = {}
     for i, (um, c_bad) in enumerate(islice(valid_urls, FEW)):
         assert not is_url_in_cache(um)
-        sources[um] = []
-        for iu in islice(invalid_urls, i):
-            sources[um].append(iu)
+        sources[um] = list(islice(invalid_urls, i))
         u, c = next(valid_urls)
         sources[um].append(u)
         urls.append((um, c, c_bad))
@@ -756,8 +752,8 @@ def test_download_parallel_many(temp_cache, valid_urls):
 
     r = download_files_in_parallel([u for (u, c) in td])
     assert len(r) == len(td)
-    for r, (u, c) in zip(r, td):
-        assert get_file_contents(r) == c
+    for r_, (_, c) in zip(r, td):
+        assert get_file_contents(r_) == c
 
 
 def test_download_parallel_partial_success(temp_cache, valid_urls, invalid_urls):
@@ -907,7 +903,7 @@ def test_find_by_hash(valid_urls, temp_cache):
 def test_find_invalid():
     # this is of course not a real data file and not on any remote server, but
     # it should *try* to go to the remote server
-    with pytest.raises(urllib.error.URLError):
+    with pytest.raises((urllib.error.URLError, TimeoutError)):
         get_pkg_data_filename(
             "kjfrhgjklahgiulrhgiuraehgiurhgiuhreglhurieghruelighiuerahiulruli"
         )
@@ -1605,12 +1601,6 @@ def test_get_fileobj_str(a_file):
         assert rf.read() == c
 
 
-def test_get_fileobj_localpath(a_file):
-    fn, c = a_file
-    with get_readable_fileobj(py.path.local(fn)) as rf:
-        assert rf.read() == c
-
-
 def test_get_fileobj_pathlib(a_file):
     fn, c = a_file
     with get_readable_fileobj(pathlib.Path(fn)) as rf:
@@ -1825,6 +1815,26 @@ def test_import_file_cache_readonly(readonly_cache, tmp_path):
     assert not is_url_in_cache(url)
 
 
+def test_import_file_cache_invalid_cross_device_link(tmp_path, monkeypatch):
+    def no_rename(path, mode=None):
+        if os.path.exists(path):
+            raise OSError(errno.EXDEV, "os.rename monkeypatched out")
+        else:
+            raise FileNotFoundError(f"File {path} does not exist.")
+
+    monkeypatch.setattr(os, "rename", no_rename)
+
+    filename = tmp_path / "test-file"
+    content = "Some text or other"
+    url = "http://example.com/"
+    with open(filename, "w") as f:
+        f.write(content)
+
+    with pytest.warns(AstropyWarning, match="os.rename monkeypatched out"):
+        import_file_to_cache(url, filename, remove_original=True, replace=True)
+    assert is_url_in_cache(url)
+
+
 def test_download_file_cache_readonly_cache_miss(readonly_cache, valid_urls):
     u, c = next(valid_urls)
     with pytest.warns(CacheMissingWarning):
@@ -2057,9 +2067,14 @@ def test_removal_of_open_files_windows(temp_cache, valid_urls, monkeypatch):
         # This platform is able to remove files while in use.
         monkeypatch.setattr(astropy.utils.data, "_rmtree", no_rmtree)
 
+    if PYTEST_LT_8_0:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.warns(CacheMissingWarning, match=".*PermissionError.*")
+
     u, c = next(valid_urls)
     with open(download_file(u, cache=True)):
-        with pytest.warns(CacheMissingWarning, match=r".*in use.*"):
+        with pytest.warns(CacheMissingWarning, match=".*in use.*"), ctx:
             clear_download_cache(u)
 
 
@@ -2072,10 +2087,15 @@ def test_update_of_open_files_windows(temp_cache, valid_urls, monkeypatch):
         # This platform is able to remove files while in use.
         monkeypatch.setattr(astropy.utils.data, "_rmtree", no_rmtree)
 
+    if PYTEST_LT_8_0:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.warns(CacheMissingWarning, match=".*read-only.*")
+
     u, c = next(valid_urls)
     with open(download_file(u, cache=True)):
         u2, c2 = next(valid_urls)
-        with pytest.warns(CacheMissingWarning, match=r".*in use.*"):
+        with pytest.warns(CacheMissingWarning, match=".*in use.*"), ctx:
             f = download_file(u, cache="update", sources=[u2])
         check_download_cache()
         assert is_url_in_cache(u)
@@ -2138,15 +2158,46 @@ def test_clear_download_cache_variants(temp_cache, valid_urls):
     assert not is_url_in_cache(u)
 
 
+def test_clear_download_cache_invalid_cross_device_link(
+    temp_cache, valid_urls, monkeypatch
+):
+    def no_rename(path, mode=None):
+        raise OSError(errno.EXDEV, "os.rename monkeypatched out")
+
+    u, c = next(valid_urls)
+    download_file(u, cache=True)
+
+    monkeypatch.setattr(os, "rename", no_rename)
+
+    assert is_url_in_cache(u)
+    with pytest.warns(AstropyWarning, match="os.rename monkeypatched out"):
+        clear_download_cache(u)
+    assert not is_url_in_cache(u)
+
+
+def test_clear_download_cache_raises_os_error(temp_cache, valid_urls, monkeypatch):
+    def no_rename(path, mode=None):
+        raise OSError(errno.EBUSY, "os.rename monkeypatched out")
+
+    u, c = next(valid_urls)
+    download_file(u, cache=True)
+
+    monkeypatch.setattr(os, "rename", no_rename)
+
+    assert is_url_in_cache(u)
+    with pytest.warns(CacheMissingWarning, match="os.rename monkeypatched out"):
+        clear_download_cache(u)
+
+
 @pytest.mark.skipif(
-    CI and os.environ.get("IS_CRON", "false") == "false",
+    CI and not IS_CRON,
     reason="Flaky/too much external traffic for regular CI",
 )
 @pytest.mark.remote_data
 def test_ftp_tls_auto(temp_cache):
     """Test that download automatically enables TLS/SSL when required"""
 
-    url = "ftp://anonymous:mail%40astropy.org@gdc.cddis.eosdis.nasa.gov/pub/products/iers/finals2000A.daily"  # noqa: E501
+    url = "ftp://anonymous:mail%40astropy.org@gdc.cddis.eosdis.nasa.gov/pub/products/iers/finals2000A.daily"
     download_file(url)
 
 
