@@ -56,7 +56,7 @@ def fits2bitmap(
         ``min_percent``.
     max_cut : float, optional
         The pixel value of the maximum cut level.  Data values greater
-        than ``min_cut`` will set to ``min_cut`` before stretching the
+        than ``max_cut`` will set to ``max_cut`` before stretching the
         image.  The default is the image maximum.  ``max_cut`` overrides
         ``max_percent``.
     min_percent : float, optional
