@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 6.4 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2019, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -18,14 +17,12 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsprintf.h,v 6.4 2019/08/15 09:30:18 mcalabre Exp $
+  $Id: wcsprintf.h,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 6.4 - C routines that implement the FITS World Coordinate System
+* WCSLIB 8.1 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -127,6 +124,7 @@
 #ifndef WCSLIB_WCSPRINTF
 #define WCSLIB_WCSPRINTF
 
+#include <inttypes.h>
 #include <stdio.h>
 
 #ifdef __cplusplus
@@ -135,7 +133,7 @@ extern "C" {
 
 #define WCSPRINTF_PTR(str1, ptr, str2) \
   if (ptr) { \
-    wcsprintf("%s%#lx%s", (str1), (unsigned long)(ptr), (str2)); \
+    wcsprintf("%s%#" PRIxPTR "%s", (str1), (uintptr_t)(ptr), (str2)); \
   } else { \
     wcsprintf("%s0x0%s", (str1), (str2)); \
   }
@@ -149,4 +147,4 @@ const char *wcsprintf_buf(void);
 }
 #endif
 
-#endif /* WCSLIB_WCSPRINTF */
+#endif // WCSLIB_WCSPRINTF
