@@ -1,11 +1,19 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 import copy
+from functools import lru_cache
 
 import numpy as np
 
 import astropy.units as u
-from astropy.coordinates import ITRS, CartesianRepresentation, SphericalRepresentation
+from astropy.coordinates import (
+    ITRS,
+    BaseBodycentricRepresentation,
+    BaseCoordinateFrame,
+    BaseGeodeticRepresentation,
+    CartesianRepresentation,
+    SphericalRepresentation,
+)
 from astropy.utils import unbroadcast
 
 from .wcs import WCS, WCSSUB_LATITUDE, WCSSUB_LONGITUDE
@@ -30,6 +38,38 @@ __all__ = [
     "fit_wcs_from_points",
 ]
 
+SOLAR_SYSTEM_OBJ_DICT = {
+    "EA": "Earth",
+    "SE": "Moon",
+    "ME": "Mercury",
+    "VE": "Venus",
+    "MA": "Mars",
+    "JU": "Jupiter",
+    "SA": "Saturn",
+    "UR": "Uranus",
+    "NE": "Neptune",
+}
+
+
+@lru_cache(maxsize=100)
+def solar_system_body_frame(object_name, representation_type):
+    return type(
+        f"{object_name}Frame",
+        (BaseCoordinateFrame,),
+        dict(name=object_name, representation_type=representation_type),
+    )
+
+
+@lru_cache(maxsize=100)
+def solar_system_body_representation_type(
+    object_name, baserepresentation, equatorial_radius, flattening
+):
+    return type(
+        f"{object_name}{baserepresentation.__name__[4:]}",
+        (baserepresentation,),
+        dict(_equatorial_radius=equatorial_radius, _flattening=flattening),
+    )
+
 
 def add_stokes_axis_to_wcs(wcs, add_before_ind):
     """
@@ -49,7 +89,6 @@ def add_stokes_axis_to_wcs(wcs, add_before_ind):
     `~astropy.wcs.WCS`
         A new `~astropy.wcs.WCS` instance with an additional axis
     """
-
     inds = [i + 1 for i in range(wcs.wcs.naxis)]
     inds.insert(add_before_ind, 0)
     newwcs = wcs.sub(inds)
@@ -119,6 +158,42 @@ def _wcs_to_celestial_frame_builtin(wcs):
                 representation_type=SphericalRepresentation,
                 obstime=wcs.wcs.dateobs or None,
             )
+        elif xcoord[2:4] in ("LN", "LT") and xcoord[:2] in SOLAR_SYSTEM_OBJ_DICT.keys():
+            # Coordinates on a planetary body, as defined in
+            # https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2018EA000388
+
+            object_name = SOLAR_SYSTEM_OBJ_DICT.get(xcoord[:2])
+
+            a_radius = wcs.wcs.aux.a_radius
+            b_radius = wcs.wcs.aux.b_radius
+            c_radius = wcs.wcs.aux.c_radius
+            if "bodycentric" in wcs.wcs.name.lower():
+                baserepresentation = BaseBodycentricRepresentation
+                representation_type_name = "BodycentricRepresentation"
+            else:
+                baserepresentation = BaseGeodeticRepresentation
+                representation_type_name = "GeodeticRepresentation"
+
+            if a_radius == b_radius:
+                equatorial_radius = a_radius * u.m
+                flattening = (a_radius - c_radius) / a_radius
+            else:
+                raise NotImplementedError(
+                    "triaxial systems are not supported at this time."
+                )
+
+            # create a new representation class
+            representation_type = solar_system_body_representation_type(
+                SOLAR_SYSTEM_OBJ_DICT.get(xcoord[:2]),
+                baserepresentation,
+                equatorial_radius,
+                flattening,
+            )
+
+            # create a new frame class
+            frame = solar_system_body_frame(
+                SOLAR_SYSTEM_OBJ_DICT.get(xcoord[:2]), representation_type
+            )
         else:
             frame = None
 
@@ -164,6 +239,25 @@ def _celestial_frame_to_wcs_builtin(frame, projection="TAN"):
         ycoord = "TLAT"
         wcs.wcs.radesys = "ITRS"
         wcs.wcs.dateobs = frame.obstime.utc.isot
+    # TODO: once we have a BaseBodyFrame, replace this with an isinstance check
+    elif hasattr(frame, "name") and frame.name in SOLAR_SYSTEM_OBJ_DICT.values():
+        xcoord = frame.name[:2].upper().replace("MO", "SE") + "LN"
+        ycoord = frame.name[:2].upper().replace("MO", "SE") + "LT"
+        if issubclass(frame.representation_type, BaseGeodeticRepresentation):
+            wcs.wcs.name = "Planetographic Body-Fixed"
+        elif issubclass(frame.representation_type, BaseBodycentricRepresentation):
+            wcs.wcs.name = "Bodycentric Body-Fixed"
+        else:
+            raise ValueError(
+                "Planetary coordinates in WCS require a geodetic or bodycentric "
+                "representation, not {frame.representation_type}."
+            )
+        wcs.wcs.aux.a_radius = frame.representation_type._equatorial_radius.value
+        wcs.wcs.aux.b_radius = frame.representation_type._equatorial_radius.value
+        wcs.wcs.aux.c_radius = wcs.wcs.aux.a_radius * (
+            1.0
+            - frame.representation_type._flattening.to(u.dimensionless_unscaled).value
+        )
     else:
         return None
 
@@ -178,7 +272,7 @@ FRAME_WCS_MAPPINGS = [[_celestial_frame_to_wcs_builtin]]
 
 class custom_wcs_to_frame_mappings:
     def __init__(self, mappings=[]):
-        if hasattr(mappings, "__call__"):
+        if callable(mappings):
             mappings = [mappings]
         WCS_FRAME_MAPPINGS.append(mappings)
 
@@ -195,7 +289,7 @@ custom_frame_mappings = custom_wcs_to_frame_mappings
 
 class custom_frame_to_wcs_mappings:
     def __init__(self, mappings=[]):
-        if hasattr(mappings, "__call__"):
+        if callable(mappings):
             mappings = [mappings]
         FRAME_WCS_MAPPINGS.append(mappings)
 
@@ -224,7 +318,6 @@ def wcs_to_celestial_frame(wcs):
 
     Notes
     -----
-
     To extend this function to frames not defined in astropy.coordinates, you
     can write your own function which should take a :class:`~astropy.wcs.WCS`
     instance and should return either an instance of a frame, or `None` if no
@@ -267,7 +360,6 @@ def celestial_frame_to_wcs(frame, projection="TAN"):
 
     Examples
     --------
-
     ::
 
         >>> from astropy.wcs.utils import celestial_frame_to_wcs
@@ -294,7 +386,6 @@ def celestial_frame_to_wcs(frame, projection="TAN"):
 
     Notes
     -----
-
     To extend this function to frames not defined in astropy.coordinates, you
     can write your own function which should take a
     :class:`~astropy.coordinates.BaseCoordinateFrame` subclass
@@ -406,7 +497,6 @@ def proj_plane_pixel_area(wcs):
 
     Notes
     -----
-
     Depending on the application, square root of the pixel area can be used to
     represent a single pixel scale of an equivalent square pixel
     whose area is equal to the area of a generally non-square pixel.
@@ -503,7 +593,6 @@ def non_celestial_pixel_scales(inwcs):
     scale : `numpy.ndarray`
         The pixel scale along each axis.
     """
-
     if inwcs.is_celestial:
         raise ValueError("WCS is celestial, use celestial_pixel_scales instead")
 
@@ -554,7 +643,6 @@ def skycoord_to_pixel(coords, wcs, origin=0, mode="all"):
     --------
     astropy.coordinates.SkyCoord.from_pixel
     """
-
     if _has_distortion(wcs) and wcs.naxis != 2:
         raise ValueError("Can only handle WCS with distortions for 2-dimensional WCS")
 
@@ -627,7 +715,6 @@ def pixel_to_skycoord(xp, yp, wcs, origin=0, mode="all", cls=None):
     --------
     astropy.coordinates.SkyCoord.from_pixel
     """
-
     # Import astropy.coordinates here to avoid circular imports
     from astropy.coordinates import SkyCoord, UnitSphericalRepresentation
 
@@ -693,7 +780,6 @@ def _pixel_to_world_correlation_matrix(wcs):
     The shape of the matrix is ``(n_world, n_pix)``, where ``n_world`` is the
     number of high level world coordinates.
     """
-
     # We basically want to collapse the world dimensions together that are
     # combined into the same high-level objects.
 
@@ -725,7 +811,6 @@ def _pixel_to_pixel_correlation_matrix(wcs_in, wcs_out):
     pixel transformation. The shape of the matrix is
     ``(n_pixel_out, n_pixel_in)``.
     """
-
     matrix1, classes1 = _pixel_to_world_correlation_matrix(wcs_in)
     matrix2, classes2 = _pixel_to_world_correlation_matrix(wcs_out)
 
@@ -777,7 +862,6 @@ def _split_matrix(matrix):
 
     and this function will return ``[([0, 1], [0, 1]), ([2], [2])]``.
     """
-
     pixel_used = []
 
     split_info = []
@@ -820,7 +904,6 @@ def pixel_to_pixel(wcs_in, wcs_out, *inputs):
     *inputs :
         Scalars or arrays giving the pixel coordinates to transform.
     """
-
     # Shortcut for scalars
     if np.isscalar(inputs[0]):
         world_outputs = wcs_in.pixel_to_world(*inputs)
@@ -879,7 +962,6 @@ def local_partial_pixel_derivatives(wcs, *pixel, normalize_by_world=False):
         If `True`, the matrix is normalized so that for each world entry
         the derivatives add up to 1.
     """
-
     # Find the world coordinates at the requested pixel
     pixel_ref = np.array(pixel)
     world_ref = np.array(wcs.pixel_to_world_values(*pixel_ref))
@@ -945,8 +1027,7 @@ def _sip_fit(params, lon, lat, u, v, w_obj, order, coeff_names):
     w_obj: `~astropy.wcs.WCS`
         WCS object
     """
-
-    from ..modeling.models import SIP  # here to avoid circular import
+    from astropy.modeling.models import SIP  # here to avoid circular import
 
     # unpack params
     crpix = params[0:2]
@@ -954,7 +1035,7 @@ def _sip_fit(params, lon, lat, u, v, w_obj, order, coeff_names):
     a_params = params[6 : 6 + len(coeff_names)]
     b_params = params[6 + len(coeff_names) :]
 
-    # assign to wcs, used for transfomations in this function
+    # assign to wcs, used for transformations in this function
     w_obj.wcs.cd = cdx
     w_obj.wcs.crpix = crpix
 
@@ -1040,7 +1121,6 @@ def fit_wcs_from_points(
     wcs : `~astropy.wcs.WCS`
         The best-fit WCS to the points given.
     """
-
     from scipy.optimize import least_squares
 
     import astropy.units as u
@@ -1059,8 +1139,8 @@ def fit_wcs_from_points(
     if (type(proj_point) != type(world_coords)) and (proj_point != "center"):
         raise ValueError(
             "proj_point must be set to 'center', or an"
-            + "`~astropy.coordinates.SkyCoord` object with "
-            + "a pair of points."
+            "`~astropy.coordinates.SkyCoord` object with "
+            "a pair of points."
         )
 
     use_center_as_proj_point = str(proj_point) == "center"
@@ -1100,8 +1180,7 @@ def fit_wcs_from_points(
     if type(projection) == str:
         if projection not in proj_codes:
             raise ValueError(
-                "Must specify valid projection code from list of "
-                + "supported types: ",
+                "Must specify valid projection code from list of supported types: ",
                 ", ".join(proj_codes),
             )
         # empty wcs to fill in with fit values
@@ -1246,7 +1325,6 @@ def obsgeo_to_frame(obsgeo, obstime):
 
     Notes
     -----
-
     The obsgeo array as accessed on a `.WCS` object is a length 6 numpy array
     where the first three elements are the coordinate in a cartesian
     representation and the second 3 are the coordinate in a spherical
