@@ -128,7 +128,7 @@ class BaseLowLevelWCS(metaclass=abc.ABCMeta):
         else:
             pixel_arrays = pixel_arrays[::-1]
         array_indices = tuple(
-            np.asarray(np.floor(pixel + 0.5), dtype=np.int_) for pixel in pixel_arrays
+            np.asarray(np.floor(pixel + 0.5), dtype=int) for pixel in pixel_arrays
         )
         return array_indices[0] if self.pixel_n_dim == 1 else array_indices
 
@@ -325,9 +325,9 @@ class BaseLowLevelWCS(metaclass=abc.ABCMeta):
         return False
 
     def _as_mpl_axes(self):
-        """
-        Compatibility hook for Matplotlib and WCSAxes. With this method, one can
-        do::
+        """Compatibility hook for Matplotlib and WCSAxes.
+
+        With this method, one can do::
 
             from astropy.wcs import WCS
             import matplotlib.pyplot as plt
@@ -351,7 +351,7 @@ with open(UCDS_FILE) as f:
 
 def validate_physical_types(physical_types):
     """
-    Validate a list of physical types against the UCD1+ standard
+    Validate a list of physical types against the UCD1+ standard.
     """
     for physical_type in physical_types:
         if (
