@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 7.3 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2020, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -18,14 +17,12 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: cel.h,v 7.3 2020/06/03 03:37:02 mcalabre Exp $
+  $Id: cel.h,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 7.3 - C routines that implement the FITS World Coordinate System
+* WCSLIB 8.1 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -51,7 +48,8 @@
 *
 * Routine celini() is provided to initialize the celprm struct with default
 * values, celfree() reclaims any memory that may have been allocated to store
-* an error message, and celprt() prints its contents.
+* an error message, celsize() computes its total size including allocated
+* memory, and celprt() prints its contents.
 *
 * celperr() prints the error message(s), if any, stored in a celprm struct and
 * the prjprm struct that it contains.
@@ -102,6 +100,33 @@
 *                         1: Null celprm pointer passed.
 *
 *
+* celsize() - Compute the size of a celprm struct
+* -----------------------------------------------
+* celsize() computes the full size of a celprm struct, including allocated
+* memory.
+*
+* Given:
+*   cel       const struct celprm*
+*                       Celestial transformation parameters.
+*
+*                       If NULL, the base size of the struct and the allocated
+*                       size are both set to zero.
+*
+* Returned:
+*   sizes     int[2]    The first element is the base size of the struct as
+*                       returned by sizeof(struct celprm).  The second element
+*                       is the total allocated size, in bytes.  This figure
+*                       includes memory allocated for the constituent struct,
+*                       celprm::err.
+*
+*                       It is not an error for the struct not to have been set
+*                       up via celset().
+*
+* Function return value:
+*             int       Status return value:
+*                         0: Success.
+*
+*
 * celprt() - Print routine for the celprm struct
 * ----------------------------------------------
 * celprt() prints the contents of a celprm struct using wcsprintf().  Mainly
@@ -382,50 +407,50 @@ extern "C" {
 extern const char *cel_errmsg[];
 
 enum cel_errmsg_enum {
-  CELERR_SUCCESS         = 0,	/* Success. */
-  CELERR_NULL_POINTER    = 1,	/* Null celprm pointer passed. */
-  CELERR_BAD_PARAM       = 2,	/* Invalid projection parameters. */
-  CELERR_BAD_COORD_TRANS = 3,	/* Invalid coordinate transformation
-				   parameters. */
-  CELERR_ILL_COORD_TRANS = 4,	/* Ill-conditioned coordinated transformation
-				   parameters. */
-  CELERR_BAD_PIX         = 5,	/* One or more of the (x,y) coordinates were
-				   invalid. */
-  CELERR_BAD_WORLD       = 6 	/* One or more of the (lng,lat) coordinates
-				   were invalid. */
+  CELERR_SUCCESS         = 0,	// Success.
+  CELERR_NULL_POINTER    = 1,	// Null celprm pointer passed.
+  CELERR_BAD_PARAM       = 2,	// Invalid projection parameters.
+  CELERR_BAD_COORD_TRANS = 3,	// Invalid coordinate transformation
+				// parameters.
+  CELERR_ILL_COORD_TRANS = 4,	// Ill-conditioned coordinated transformation
+				// parameters.
+  CELERR_BAD_PIX         = 5,	// One or more of the (x,y) coordinates were
+				// invalid.
+  CELERR_BAD_WORLD       = 6 	// One or more of the (lng,lat) coordinates
+				// were invalid.
 };
 
 struct celprm {
-  /* Initialization flag (see the prologue above).                          */
-  /*------------------------------------------------------------------------*/
-  int    flag;			/* Set to zero to force initialization.     */
+  // Initialization flag (see the prologue above).
+  //--------------------------------------------------------------------------
+  int    flag;			// Set to zero to force initialization.
 
-  /* Parameters to be provided (see the prologue above).                    */
-  /*------------------------------------------------------------------------*/
-  int    offset;		/* Force (x,y) = (0,0) at (phi_0,theta_0).  */
-  double phi0, theta0;		/* Native coordinates of fiducial point.    */
-  double ref[4];		/* Celestial coordinates of fiducial        */
-                                /* point and native coordinates of          */
-                                /* celestial pole.                          */
+  // Parameters to be provided (see the prologue above).
+  //--------------------------------------------------------------------------
+  int    offset;		// Force (x,y) = (0,0) at (phi_0,theta_0).
+  double phi0, theta0;		// Native coordinates of fiducial point.
+  double ref[4];		// Celestial coordinates of fiducial
+                                // point and native coordinates of
+                                // celestial pole.
 
-  struct prjprm prj;		/* Projection parameters (see prj.h).       */
+  struct prjprm prj;		// Projection parameters (see prj.h).
 
-  /* Information derived from the parameters supplied.                      */
-  /*------------------------------------------------------------------------*/
-  double euler[5];		/* Euler angles and functions thereof.      */
-  int    latpreq;		/* LATPOLEa requirement.                    */
-  int    isolat;		/* True if |latitude| is preserved.         */
+  // Information derived from the parameters supplied.
+  //--------------------------------------------------------------------------
+  double euler[5];		// Euler angles and functions thereof.
+  int    latpreq;		// LATPOLEa requirement.
+  int    isolat;		// True if |latitude| is preserved.
 
-  /* Error handling                                                         */
-  /*------------------------------------------------------------------------*/
+  // Error handling
+  //--------------------------------------------------------------------------
   struct wcserr *err;
 
-  /* Private                                                                */
-  /*------------------------------------------------------------------------*/
-  void   *padding;		/* (Dummy inserted for alignment purposes.) */
+  // Private
+  //--------------------------------------------------------------------------
+  void   *padding;		// (Dummy inserted for alignment purposes.)
 };
 
-/* Size of the celprm struct in int units, used by the Fortran wrappers. */
+// Size of the celprm struct in int units, used by the Fortran wrappers.
 #define CELLEN (sizeof(struct celprm)/sizeof(int))
 
 
@@ -433,6 +458,8 @@ int celini(struct celprm *cel);
 
 int celfree(struct celprm *cel);
 
+int celsize(const struct celprm *cel, int sizes[2]);
+
 int celprt(const struct celprm *cel);
 
 int celperr(const struct celprm *cel, const char *prefix);
@@ -450,7 +477,7 @@ int cels2x(struct celprm *cel, int nlng, int nlat, int sll, int sxy,
            int stat[]);
 
 
-/* Deprecated. */
+// Deprecated.
 #define celini_errmsg cel_errmsg
 #define celprt_errmsg cel_errmsg
 #define celset_errmsg cel_errmsg
@@ -461,4 +488,4 @@ int cels2x(struct celprm *cel, int nlng, int nlat, int sll, int sxy,
 }
 #endif
 
-#endif /* WCSLIB_CEL */
+#endif // WCSLIB_CEL
