@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.9 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2022, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: log.c,v 7.9 2022/03/25 15:14:48 mcalabre Exp $
+  $Id: log.c,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *===========================================================================*/
 
 #include <math.h>
@@ -60,9 +60,9 @@ int logx2s(
   xp = x;
   logcp = logc;
   statp = stat;
-  for (ix = 0; ix < nx; ix++, xp += sx, logcp += slogc) {
+  for (ix = 0; ix < nx; ix++, xp += sx, logcp += slogc, statp++) {
     *logcp = crval * exp((*xp) / crval);
-    *(statp++) = 0;
+    *statp = 0;
   }
 
   return 0;
@@ -95,13 +95,13 @@ int logs2x(
   logcp = logc;
   statp = stat;
   status = 0;
-  for (ilogc = 0; ilogc < nlogc; ilogc++, logcp += slogc, xp += sx) {
+  for (ilogc = 0; ilogc < nlogc; ilogc++, logcp += slogc, xp += sx, statp++) {
     if (*logcp > 0.0) {
       *xp = crval * log(*logcp / crval);
-      *(statp++) = 0;
+      *statp = 0;
     } else {
-      *(statp++) = 1;
       status = LOGERR_BAD_WORLD;
+      *statp = 1;
     }
   }
 
