@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 4.16 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2012, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -18,41 +17,42 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: spc.h,v 4.16 2012/11/07 04:42:44 cal103 Exp $
+  $Id: spc.h,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 4.16 - C routines that implement the spectral coordinate systems
-* recognized by the FITS World Coordinate System (WCS) standard.  Refer to
-*
-*   "Representations of world coordinates in FITS",
-*   Greisen, E.W., & Calabretta, M.R. 2002, A&A, 395, 1061 (Paper I)
-*
-*   "Representations of spectral coordinates in FITS",
-*   Greisen, E.W., Calabretta, M.R., Valdes, F.G., & Allen, S.L.
-*   2006, A&A, 446, 747 (Paper III)
-*
-* Refer to the README file provided with WCSLIB for an overview of the
-* library.
+* WCSLIB 8.1 - C routines that implement the FITS World Coordinate System
+* (WCS) standard.  Refer to the README file provided with WCSLIB for an
+* overview of the library.
 *
 *
 * Summary of the spc routines
 * ---------------------------
-* These routines implement the part of the FITS WCS standard that deals with
-* spectral coordinates.  They define methods to be used for computing spectral
-* world coordinates from intermediate world coordinates (a linear
-* transformation of image pixel coordinates), and vice versa.  They are based
-* on the spcprm struct which contains all information needed for the
-* computations.  The struct contains some members that must be set by the
-* user, and others that are maintained by these routines, somewhat like a
-* C++ class but with no encapsulation.
+* Routines in this suite implement the part of the FITS World Coordinate
+* System (WCS) standard that deals with spectral coordinates, as described in
+*
+=   "Representations of world coordinates in FITS",
+=   Greisen, E.W., & Calabretta, M.R. 2002, A&A, 395, 1061 (WCS Paper I)
+=
+=   "Representations of spectral coordinates in FITS",
+=   Greisen, E.W., Calabretta, M.R., Valdes, F.G., & Allen, S.L.
+=   2006, A&A, 446, 747 (WCS Paper III)
+*
+* These routines define methods to be used for computing spectral world
+* coordinates from intermediate world coordinates (a linear transformation
+* of image pixel coordinates), and vice versa.  They are based on the spcprm
+* struct which contains all information needed for the computations.  The
+* struct contains some members that must be set by the user, and others that
+* are maintained by these routines, somewhat like a C++ class but with no
+* encapsulation.
 *
 * Routine spcini() is provided to initialize the spcprm struct with default
 * values, spcfree() reclaims any memory that may have been allocated to store
-* an error message, and spcprt() prints its contents.
+* an error message, spcsize() computes its total size including allocated
+* memory, and spcprt() prints its contents.
+*
+* spcperr() prints the error message(s) (if any) stored in a spcprm struct.
 *
 * A setup routine, spcset(), computes intermediate values in the spcprm struct
 * from parameters in it that were supplied by the user.  The struct always
@@ -92,24 +92,24 @@
 *     expressed.  Each S-type is encoded as four characters and is
 *     linearly related to one of four basic types as follows:
 *
-*     F: frequency
-*       'FREQ':  frequency
-*       'AFRQ':  angular frequency
-*       'ENER':  photon energy
-*       'WAVN':  wave number
-*       'VRAD':  radio velocity
+*     F (Frequency):
+*       - 'FREQ':  frequency
+*       - 'AFRQ':  angular frequency
+*       - 'ENER':  photon energy
+*       - 'WAVN':  wave number
+*       - 'VRAD':  radio velocity
 *
-*     W: wavelength in vacuo
-*       'WAVE':  wavelength
-*       'VOPT':  optical velocity
-*       'ZOPT':  redshift
+*     W (Wavelength in vacuo):
+*       - 'WAVE':  wavelength
+*       - 'VOPT':  optical velocity
+*       - 'ZOPT':  redshift
 *
-*     A: wavelength in air
-*       'AWAV':  wavelength in air
+*     A (wavelength in Air):
+*       - 'AWAV':  wavelength in air
 *
-*     V: velocity
-*       'VELO':  relativistic velocity
-*       'BETA':  relativistic beta factor
+*     V (Velocity):
+*       - 'VELO':  relativistic velocity
+*       - 'BETA':  relativistic beta factor
 *
 *     The S-type forms the first four characters of the CTYPEia keyvalue,
 *     and CRVALia and CDELTia are expressed as S-type quantities so that
@@ -154,6 +154,11 @@
 * (wavelength), and the X-type is 'F' (frequency) by the nature of the
 * instrument.
 *
+* Air-to-vacuum wavelength conversion:
+* ------------------------------------
+* Please refer to the prologue of spx.h for important comments relating to the
+* air-to-vacuum wavelength conversion.
+*
 * Argument checking:
 * ------------------
 * The input spectral values are only checked for values that would result in
@@ -176,6 +181,11 @@
 * spcini() sets all members of a spcprm struct to default values.  It should
 * be used to initialize every spcprm struct.
 *
+* PLEASE NOTE: If the spcprm struct has already been initialized, then before
+* reinitializing, it spcfree() should be used to free any memory that may have
+* been allocated to store an error message.  A memory leak may otherwise
+* result.
+*
 * Given and returned:
 *   spc       struct spcprm*
 *                       Spectral transformation parameters.
@@ -201,6 +211,33 @@
 *                         1: Null spcprm pointer passed.
 *
 *
+* spcsize() - Compute the size of a spcprm struct
+* -----------------------------------------------
+* spcsize() computes the full size of a spcprm struct, including allocated
+* memory.
+*
+* Given:
+*   spc       const struct spcprm*
+*                       Spectral transformation parameters.
+*
+*                       If NULL, the base size of the struct and the allocated
+*                       size are both set to zero.
+*
+* Returned:
+*   sizes     int[2]    The first element is the base size of the struct as
+*                       returned by sizeof(struct spcprm).  The second element
+*                       is the total allocated size, in bytes.  This figure
+*                       includes memory allocated for the constituent struct,
+*                       spcprm::err.
+*
+*                       It is not an error for the struct not to have been set
+*                       up via spcset().
+*
+* Function return value:
+*             int       Status return value:
+*                         0: Success.
+*
+*
 * spcprt() - Print routine for the spcprm struct
 * ----------------------------------------------
 * spcprt() prints the contents of a spcprm struct using wcsprintf().  Mainly
@@ -216,6 +253,25 @@
 *                         1: Null spcprm pointer passed.
 *
 *
+* spcperr() - Print error messages from a spcprm struct
+* -----------------------------------------------------
+* spcperr() prints the error message(s) (if any) stored in a spcprm struct.
+* If there are no errors then nothing is printed.  It uses wcserr_prt(), q.v.
+*
+* Given:
+*   spc       const struct spcprm*
+*                       Spectral transformation parameters.
+*
+*   prefix    const char *
+*                       If non-NULL, each output line will be prefixed with
+*                       this string.
+*
+* Function return value:
+*             int       Status return value:
+*                         0: Success.
+*                         1: Null spcprm pointer passed.
+*
+*
 * spcset() - Setup routine for the spcprm struct
 * ----------------------------------------------
 * spcset() sets up a spcprm struct according to information supplied within
@@ -627,6 +683,9 @@
 *
 *                       returns ctype = 'VOPT' with specsys set to 'LSRK'.
 *
+*                       If omitted from the header, the default value of
+*                       VELREF is 0.
+*
 * Returned:
 *   ctype     char[9]   Translated CTYPEia keyvalue, or a copy of ctypeA if no
 *                       translation was performed (in which case any trailing
@@ -719,7 +778,7 @@
 *     (An unused variable inserted for alignment purposes only.)
 *
 *   struct wcserr *err
-*     (Returned) If enabled, when an error status is returned this structure
+*     (Returned) If enabled, when an error status is returned, this struct
 *     contains detailed information about the error, see wcserr_enable().
 *
 *   void *padding2
@@ -751,7 +810,6 @@
 #define WCSLIB_SPC
 
 #include "spx.h"
-#include "wcserr.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -761,67 +819,67 @@ extern "C" {
 extern const char *spc_errmsg[];
 
 enum spc_errmsg_enum {
-  SPCERR_NO_CHANGE       = -1,	/* No change. */
-  SPCERR_SUCCESS         =  0,	/* Success. */
-  SPCERR_NULL_POINTER    =  1,	/* Null spcprm pointer passed. */
-  SPCERR_BAD_SPEC_PARAMS =  2,	/* Invalid spectral parameters. */
-  SPCERR_BAD_X           =  3,	/* One or more of x coordinates were
-				   invalid. */
-  SPCERR_BAD_SPEC        =  4 	/* One or more of the spec coordinates were
-				   invalid. */
+  SPCERR_NO_CHANGE       = -1,	// No change.
+  SPCERR_SUCCESS         =  0,	// Success.
+  SPCERR_NULL_POINTER    =  1,	// Null spcprm pointer passed.
+  SPCERR_BAD_SPEC_PARAMS =  2,	// Invalid spectral parameters.
+  SPCERR_BAD_X           =  3,	// One or more of x coordinates were
+				// invalid.
+  SPCERR_BAD_SPEC        =  4 	// One or more of the spec coordinates were
+				// invalid.
 };
 
 struct spcprm {
-  /* Initialization flag (see the prologue above).                          */
-  /*------------------------------------------------------------------------*/
-  int    flag;			/* Set to zero to force initialization.     */
+  // Initialization flag (see the prologue above).
+  //--------------------------------------------------------------------------
+  int    flag;			// Set to zero to force initialization.
 
-  /* Parameters to be provided (see the prologue above).                    */
-  /*------------------------------------------------------------------------*/
-  char   type[8];		/* Four-letter spectral variable type.      */
-  char   code[4];		/* Three-letter spectral algorithm code.    */
+  // Parameters to be provided (see the prologue above).
+  //--------------------------------------------------------------------------
+  char   type[8];		// Four-letter spectral variable type.
+  char   code[4];		// Three-letter spectral algorithm code.
 
-  double crval;			/* Reference value (CRVALia), SI units.     */
-  double restfrq;		/* Rest frequency, Hz.                      */
-  double restwav;		/* Rest wavelength, m.                      */
+  double crval;			// Reference value (CRVALia), SI units.
+  double restfrq;		// Rest frequency, Hz.
+  double restwav;		// Rest wavelength, m.
 
-  double pv[7];			/* Grism parameters:                        */
-				/*   0: G, grating ruling density.          */
-				/*   1: m, interference order.              */
-				/*   2: alpha, angle of incidence.          */
-				/*   3: n_r, refractive index at lambda_r.  */
-				/*   4: n'_r, dn/dlambda at lambda_r.       */
-				/*   5: epsilon, grating tilt angle.        */
-				/*   6: theta, detector tilt angle.         */
+  double pv[7];			// Grism parameters:
+				//   0: G, grating ruling density.
+				//   1: m, interference order.
+				//   2: alpha, angle of incidence.
+				//   3: n_r, refractive index at lambda_r.
+				//   4: n'_r, dn/dlambda at lambda_r.
+				//   5: epsilon, grating tilt angle.
+				//   6: theta, detector tilt angle.
 
-  /* Information derived from the parameters supplied.                      */
-  /*------------------------------------------------------------------------*/
-  double w[6];			/* Intermediate values.                     */
-				/*   0: Rest frequency or wavelength (SI).  */
-				/*   1: CRVALX (SI units).                  */
-				/*   2: CDELTX/CDELTia = dX/dS (SI units).  */
-				/* The remainder are grism intermediates.   */
+  // Information derived from the parameters supplied.
+  //--------------------------------------------------------------------------
+  double w[6];			// Intermediate values.
+				//   0: Rest frequency or wavelength (SI).
+				//   1: CRVALX (SI units).
+				//   2: CDELTX/CDELTia = dX/dS (SI units).
+				// The remainder are grism intermediates.
 
-  int    isGrism;		/* Grism coordinates?  1: vacuum, 2: air.   */
-  int    padding1;		/* (Dummy inserted for alignment purposes.) */
+  int    isGrism;		// Grism coordinates?  1: vacuum, 2: air.
+  int    padding1;		// (Dummy inserted for alignment purposes.)
 
-  /* Error handling                                                         */
-  /*------------------------------------------------------------------------*/
+  // Error handling
+  //--------------------------------------------------------------------------
   struct wcserr *err;
 
-  /* Private                                                                */
-  /*------------------------------------------------------------------------*/
-  void   *padding2;		/* (Dummy inserted for alignment purposes.) */
-  int (*spxX2P)(SPX_ARGS);	/* Pointers to the transformation functions */
-  int (*spxP2S)(SPX_ARGS);	/* in the two-step algorithm chain in the   */
-				/* pixel-to-spectral direction.             */
+  // Private
+  //--------------------------------------------------------------------------
+  void   *padding2;		// (Dummy inserted for alignment purposes.)
+  int (*spxX2P)(SPX_ARGS);	// Pointers to the transformation functions
+  int (*spxP2S)(SPX_ARGS);	// in the two-step algorithm chain in the
+				// pixel-to-spectral direction.
 
-  int (*spxS2P)(SPX_ARGS);	/* Pointers to the transformation functions */
-  int (*spxP2X)(SPX_ARGS);	/* in the two-step algorithm chain in the   */
-				/* spectral-to-pixel direction.             */
+  int (*spxS2P)(SPX_ARGS);	// Pointers to the transformation functions
+  int (*spxP2X)(SPX_ARGS);	// in the two-step algorithm chain in the
+				// spectral-to-pixel direction.
 };
 
-/* Size of the spcprm struct in int units, used by the Fortran wrappers. */
+// Size of the spcprm struct in int units, used by the Fortran wrappers.
 #define SPCLEN (sizeof(struct spcprm)/sizeof(int))
 
 
@@ -829,8 +887,12 @@ int spcini(struct spcprm *spc);
 
 int spcfree(struct spcprm *spc);
 
+int spcsize(const struct spcprm *spc, int sizes[2]);
+
 int spcprt(const struct spcprm *spc);
 
+int spcperr(const struct spcprm *spc, const char *prefix);
+
 int spcset(struct spcprm *spc);
 
 int spcx2s(struct spcprm *spc, int nx, int sx, int sspec,
@@ -839,46 +901,46 @@ int spcx2s(struct spcprm *spc, int nx, int sx, int sspec,
 int spcs2x(struct spcprm *spc, int nspec, int sspec, int sx,
            const double spec[], double x[], int stat[]);
 
-int spctype(const char ctype[], char stype[], char scode[], char sname[],
+int spctype(const char ctype[9], char stype[], char scode[], char sname[],
             char units[], char *ptype, char *xtype, int *restreq,
             struct wcserr **err);
 
-int spcspxe(const char ctypeS[], double crvalS, double restfrq,
+int spcspxe(const char ctypeS[9], double crvalS, double restfrq,
             double restwav, char *ptype, char *xtype, int *restreq,
             double *crvalX, double *dXdS, struct wcserr **err);
 
-int spcxpse(const char ctypeS[], double crvalX, double restfrq,
+int spcxpse(const char ctypeS[9], double crvalX, double restfrq,
             double restwav, char *ptype, char *xtype, int *restreq,
             double *crvalS, double *dSdX, struct wcserr **err);
 
-int spctrne(const char ctypeS1[], double crvalS1, double cdeltS1,
-            double restfrq, double restwav, char ctypeS2[], double *crvalS2,
+int spctrne(const char ctypeS1[9], double crvalS1, double cdeltS1,
+            double restfrq, double restwav, char ctypeS2[9], double *crvalS2,
             double *cdeltS2, struct wcserr **err);
 
-int spcaips(const char ctypeA[], int velref, char ctype[], char specsys[]);
+int spcaips(const char ctypeA[9], int velref, char ctype[9], char specsys[9]);
 
 
-/* Deprecated. */
+// Deprecated.
 #define spcini_errmsg spc_errmsg
 #define spcprt_errmsg spc_errmsg
 #define spcset_errmsg spc_errmsg
 #define spcx2s_errmsg spc_errmsg
 #define spcs2x_errmsg spc_errmsg
 
-int spctyp(const char ctype[], char stype[], char scode[], char sname[],
+int spctyp(const char ctype[9], char stype[], char scode[], char sname[],
            char units[], char *ptype, char *xtype, int *restreq);
-int spcspx(const char ctypeS[], double crvalS, double restfrq, double restwav,
-           char *ptype, char *xtype, int *restreq, double *crvalX,
-           double *dXdS);
-int spcxps(const char ctypeS[], double crvalX, double restfrq, double restwav,
-           char *ptype, char *xtype, int *restreq, double *crvalS,
-           double *dSdX);
-int spctrn(const char ctypeS1[], double crvalS1, double cdeltS1,
-           double restfrq, double restwav, char ctypeS2[], double *crvalS2,
+int spcspx(const char ctypeS[9], double crvalS, double restfrq,
+           double restwav, char *ptype, char *xtype, int *restreq,
+           double *crvalX, double *dXdS);
+int spcxps(const char ctypeS[9], double crvalX, double restfrq,
+           double restwav, char *ptype, char *xtype, int *restreq,
+           double *crvalS, double *dSdX);
+int spctrn(const char ctypeS1[9], double crvalS1, double cdeltS1,
+           double restfrq, double restwav, char ctypeS2[9], double *crvalS2,
            double *cdeltS2);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* WCSLIB_SPC */
+#endif // WCSLIB_SPC
