@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.9 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2022, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: tab.c,v 7.9 2022/03/25 15:14:48 mcalabre Exp $
+  $Id: tab.c,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *===========================================================================*/
 
 #include <math.h>
@@ -246,7 +246,8 @@ int tabini(int alloc, int M, const int K[], struct tabprm *tab)
       tab->K[m] = K[m];
       double *dp;
       if ((dp = tab->index[m])) {
-        for (int k = 0; k < K[m]; k++) {
+        // Table indexes are 1-relative.
+        for (int k = 1; k <= K[m]; k++) {
           *(dp++) = k;
         }
       }
@@ -389,6 +390,12 @@ int tabcpy(int alloc, const struct tabprm *tabsrc, struct tabprm *tabdst)
       for (int k = 0; k < tabsrc->K[m]; k++) {
         *(dstp++) = *(srcp++);
       }
+    } else {
+      if (tabdst->m_indxs && tabdst->m_indxs[m]) {
+        free(tabdst->m_indxs[m]);
+        tabdst->index[m]   = 0x0;
+        tabdst->m_indxs[m] = 0x0;
+      }
     }
   }
 
@@ -643,8 +650,8 @@ int tabprt(const struct tabprm *tab)
         }
         wcsprintf("  %#- 11.5g", tab->index[m][k]);
       }
-      wcsprintf("\n");
     }
+    wcsprintf("\n");
   }
 
   // Coordinate array.
