@@ -27,7 +27,7 @@ os.mkdir(os.path.join(os.environ["XDG_CACHE_HOME"], "astropy"))
 
 @pytest.fixture(autouse=True)
 def _docdir(request):
-    """Run doctests in isolated tmp_path so outputs do not end up in repo"""
+    """Run doctests in isolated tmp_path so outputs do not end up in repo."""
     # Trigger ONLY for doctestplus
     doctest_plugin = request.config.pluginmanager.getplugin("doctestplus")
     if isinstance(request.node.parent, doctest_plugin._doctest_textfile_item_cls):
